@@ -32,6 +32,7 @@
 #include "core/gimpimage.h"
 
 #include "widgets/gimpactionfactory.h"
+#include "widgets/gimpactiongroup.h"
 #include "widgets/gimpcontainereditor.h"
 #include "widgets/gimpcontainerview.h"
 #include "widgets/gimpdock.h"
@@ -72,6 +73,7 @@
 #include "qmask-actions.h"
 #include "select-actions.h"
 #include "templates-actions.h"
+#include "text-editor-actions.h"
 #include "tool-options-actions.h"
 #include "tools-actions.h"
 #include "vectors-actions.h"
@@ -170,6 +172,9 @@ static GimpActionFactoryEntry action_groups[] =
   { "templates", N_("Templates"), GIMP_STOCK_TEMPLATE,
     templates_actions_setup,
     templates_actions_update },
+  { "text-editor", N_("Text Editor"), GIMP_STOCK_EDIT,
+    text_editor_actions_setup,
+    text_editor_actions_update },
   { "tool-options", N_("Tool Options"), GIMP_STOCK_TOOL_OPTIONS,
     tool_options_actions_setup,
     tool_options_actions_update },
@@ -224,26 +229,26 @@ actions_exit (Gimp *gimp)
 Gimp *
 action_data_get_gimp (gpointer data)
 {
+  GimpContext *context = NULL;
+
   if (! data)
     return NULL;
 
-#ifdef __GNUC__
-#warning FIXME: remove g_assert() before 2.2
-#endif
-  g_assert (! GIMP_IS_DISPLAY_SHELL (data));
-
   if (GIMP_IS_DISPLAY (data))
     return ((GimpDisplay *) data)->gimage->gimp;
-  else if (GIMP_IS_ITEM_TREE_VIEW (data))
-    return ((GimpItemTreeView *) data)->context->gimp;
-  else if (GIMP_IS_IMAGE_EDITOR (data))
-    return ((GimpImageEditor *) data)->context->gimp;
-  else if (GIMP_IS_NAVIGATION_EDITOR (data))
-    return ((GimpNavigationEditor *) data)->context->gimp;
   else if (GIMP_IS_GIMP (data))
     return data;
   else if (GIMP_IS_DOCK (data))
-    return ((GimpDock *) data)->context->gimp;
+    context = ((GimpDock *) data)->context;
+  else if (GIMP_IS_ITEM_TREE_VIEW (data))
+    context = ((GimpItemTreeView *) data)->context;
+  else if (GIMP_IS_IMAGE_EDITOR (data))
+    context = ((GimpImageEditor *) data)->context;
+  else if (GIMP_IS_NAVIGATION_EDITOR (data))
+    context = ((GimpNavigationEditor *) data)->context;
+
+  if (context)
+    return context->gimp;
 
   return NULL;
 }
@@ -254,13 +259,12 @@ action_data_get_context (gpointer data)
   if (! data)
     return NULL;
 
-#ifdef __GNUC__
-#warning FIXME: remove g_assert() before 2.2
-#endif
-  g_assert (! GIMP_IS_DISPLAY_SHELL (data));
-
   if (GIMP_IS_DISPLAY (data))
     return gimp_get_user_context (((GimpDisplay *) data)->gimage->gimp);
+  else if (GIMP_IS_GIMP (data))
+    return gimp_get_user_context (data);
+  else if (GIMP_IS_DOCK (data))
+    return ((GimpDock *) data)->context;
   else if (GIMP_IS_ITEM_TREE_VIEW (data))
     return ((GimpItemTreeView *) data)->context;
   else if (GIMP_IS_CONTAINER_VIEW (data))
@@ -271,10 +275,6 @@ action_data_get_context (gpointer data)
     return ((GimpImageEditor *) data)->context;
   else if (GIMP_IS_NAVIGATION_EDITOR (data))
     return ((GimpNavigationEditor *) data)->context;
-  else if (GIMP_IS_GIMP (data))
-    return gimp_get_user_context (data);
-  else if (GIMP_IS_DOCK (data))
-    return ((GimpDock *) data)->context;
 
   return NULL;
 }
@@ -282,26 +282,26 @@ action_data_get_context (gpointer data)
 GimpImage *
 action_data_get_image (gpointer data)
 {
+  GimpContext *context = NULL;
+
   if (! data)
     return NULL;
 
-#ifdef __GNUC__
-#warning FIXME: remove g_assert() before 2.2
-#endif
-  g_assert (! GIMP_IS_DISPLAY_SHELL (data));
-
   if (GIMP_IS_DISPLAY (data))
     return ((GimpDisplay *) data)->gimage;
+  else if (GIMP_IS_GIMP (data))
+    context = gimp_get_user_context (data);
+  else if (GIMP_IS_DOCK (data))
+    context = ((GimpDock *) data)->context;
   else if (GIMP_IS_ITEM_TREE_VIEW (data))
     return ((GimpItemTreeView *) data)->gimage;
   else if (GIMP_IS_IMAGE_EDITOR (data))
     return ((GimpImageEditor *) data)->gimage;
   else if (GIMP_IS_NAVIGATION_EDITOR (data))
-    return gimp_context_get_image (((GimpNavigationEditor *) data)->context);
-  else if (GIMP_IS_GIMP (data))
-    return gimp_context_get_image (gimp_get_user_context (data));
-  else if (GIMP_IS_DOCK (data))
-    return gimp_context_get_image (((GimpDock *) data)->context);
+    context = ((GimpNavigationEditor *) data)->context;
+
+  if (context)
+    return gimp_context_get_image (context);
 
   return NULL;
 }
@@ -309,22 +309,22 @@ action_data_get_image (gpointer data)
 GimpDisplay *
 action_data_get_display (gpointer data)
 {
+  GimpContext *context = NULL;
+
   if (! data)
     return NULL;
 
-#ifdef __GNUC__
-#warning FIXME: remove g_assert() before 2.2
-#endif
-  g_assert (! GIMP_IS_DISPLAY_SHELL (data));
-
   if (GIMP_IS_DISPLAY (data))
     return data;
-  else if (GIMP_IS_NAVIGATION_EDITOR (data))
-    return gimp_context_get_display (((GimpNavigationEditor *) data)->context);
   else if (GIMP_IS_GIMP (data))
-    return gimp_context_get_display (gimp_get_user_context (data));
+    context = gimp_get_user_context (data);
   else if (GIMP_IS_DOCK (data))
-    return gimp_context_get_display (((GimpDock *) data)->context);
+    context = ((GimpDock *) data)->context;
+  else if (GIMP_IS_NAVIGATION_EDITOR (data))
+    context = ((GimpNavigationEditor *) data)->context;
+
+  if (context)
+    return gimp_context_get_display (context);
 
   return NULL;
 }
@@ -335,11 +335,6 @@ action_data_get_widget (gpointer data)
   if (! data)
     return NULL;
 
-#ifdef __GNUC__
-#warning FIXME: remove g_assert() before 2.2
-#endif
-  g_assert (! GIMP_IS_DISPLAY_SHELL (data));
-
   if (GIMP_IS_DISPLAY (data))
     return ((GimpDisplay *) data)->shell;
   else if (GIMP_IS_GIMP (data))
