@@ -136,6 +136,9 @@ dump_gimprc_system (GimpConfig       *rc,
       if (! (prop_spec->flags & GIMP_PARAM_SERIALIZE))
         continue;
 
+      if (prop_spec->flags & GIMP_PARAM_IGNORE)
+        continue;
+
       comment = dump_describe_param (prop_spec);
       if (comment)
 	{
@@ -178,11 +181,11 @@ static const gchar *man_page_header =
 "file associates values with properties.  These properties may be set\n"
 "by lisp-like assignments of the form:\n"
 ".IP\n"
-"\\f3(\\f2property-name\\ value\\f3)\\f1\n"
+"\\f3(\\f2property\\-name\\ value\\f3)\\f1\n"
 ".TP\n"
 "where:\n"
 ".TP 10\n"
-".I property-name\n"
+".I property\\-name\n"
 "is one of the property names described below.\n"
 ".TP\n"
 ".I value\n"
@@ -239,7 +242,7 @@ static const gchar *man_page_footer =
 ".SH \"SEE ALSO\"\n"
 ".BR gimp (1),\n"
 ".BR gimptool (1),\n"
-".BR gimp-remote (1)\n";
+".BR gimp\\-remote (1)\n";
 
 
 static void
@@ -265,6 +268,9 @@ dump_gimprc_manpage (GimpConfig       *rc,
       if (! (prop_spec->flags & GIMP_PARAM_SERIALIZE))
         continue;
 
+      if (prop_spec->flags & GIMP_PARAM_IGNORE)
+        continue;
+
       write (fd, ".TP\n", strlen (".TP\n"));
 
       if (gimp_config_serialize_property (rc, prop_spec, writer))
@@ -487,13 +493,17 @@ static void
 dump_with_linebreaks (gint         fd,
 		      const gchar *text)
 {
-  const gchar *t;
-  gint         i, len, space;
-
-  len = strlen (text);
+  gint len = strlen (text);
 
   while (len > 0)
     {
+      const gchar *t;
+      gint         i, space;
+
+      /*  groff doesn't like lines to start with a single quote  */
+      if (*text == '\'')
+        write (fd, "\\&", 2);  /*  this represents a zero width space  */
+
       for (t = text, i = 0, space = 0;
            *t != '\n' && (i <= LINE_LENGTH || space == 0) && i < len;
            t++, i++)
