@@ -25,6 +25,8 @@
 #include <glib-object.h>
 #include <gobject/gvaluecollector.h>
 
+#include "libgimpcolor/gimpcolor.h"
+
 #include "core-types.h"
 
 #include "config/gimpconfig-types.h"
@@ -115,7 +117,7 @@ gimp_g_value_get_memsize (GValue *value)
     }
   else if (G_VALUE_HOLDS_BOXED (value))
     {
-      if (GIMP_VALUE_HOLDS_COLOR (value))
+      if (GIMP_VALUE_HOLDS_RGB (value))
         {
           memsize += sizeof (GimpRGB);
         }
@@ -302,3 +304,26 @@ gimp_parameters_free (GParameter *params,
       g_free (params);
     }
 }
+
+const gchar *
+gimp_check_glib_version (guint required_major,
+                         guint required_minor,
+                         guint required_micro)
+{
+#ifdef __GNUC__
+#warning FIXME: remove this function as soon as we depend on GLib 2.6.0
+#endif
+
+  gint glib_effective_micro = 100 * glib_minor_version + glib_micro_version;
+  gint required_effective_micro = 100 * required_minor + required_micro;
+
+  if (required_major > glib_major_version)
+    return "GLib version too old (major mismatch)";
+  if (required_major < glib_major_version)
+    return "GLib version too new (major mismatch)";
+  if (required_effective_micro < glib_effective_micro - glib_binary_age)
+    return "GLib version too new (micro mismatch)";
+  if (required_effective_micro > glib_effective_micro)
+    return "GLib version too old (micro mismatch)";
+  return NULL;
+}
