@@ -52,7 +52,7 @@
 #include "gimpmarshal.h"
 #include "gimppaintinfo.h"
 #include "gimpprojection.h"
-#include "gimpstrokeoptions.h"
+#include "gimpstrokedesc.h"
 
 #include "gimp-intl.h"
 
@@ -119,7 +119,7 @@ static void       gimp_channel_transform     (GimpItem         *item,
 static gboolean   gimp_channel_stroke        (GimpItem         *item,
                                               GimpDrawable     *drawable,
                                               GimpContext      *context,
-                                              GimpObject       *stroke_desc);
+                                              GimpStrokeDesc   *stroke_desc);
 
 static void gimp_channel_invalidate_boundary   (GimpDrawable       *drawable);
 static void gimp_channel_get_active_components (const GimpDrawable *drawable,
@@ -610,10 +610,10 @@ gimp_channel_transform (GimpItem               *item,
 }
 
 static gboolean
-gimp_channel_stroke (GimpItem     *item,
-                     GimpDrawable *drawable,
-                     GimpContext  *context,
-                     GimpObject   *stroke_desc)
+gimp_channel_stroke (GimpItem       *item,
+                     GimpDrawable   *drawable,
+                     GimpContext    *context,
+                     GimpStrokeDesc *stroke_desc)
 
 {
   GimpChannel    *channel = GIMP_CHANNEL (item);
@@ -634,27 +634,33 @@ gimp_channel_stroke (GimpItem     *item,
 
   gimp_item_offsets (GIMP_ITEM (channel), &offset_x, &offset_y);
 
-  if (GIMP_IS_STROKE_OPTIONS (stroke_desc))
+  switch (stroke_desc->method)
     {
+    case GIMP_STROKE_METHOD_LIBART:
       gimp_drawable_stroke_boundary (drawable,
-                                     GIMP_STROKE_OPTIONS (stroke_desc),
+                                     stroke_desc->stroke_options,
                                      segs_in, n_segs_in,
                                      offset_x, offset_y);
       retval = TRUE;
-    }
-  else if (GIMP_IS_PAINT_OPTIONS (stroke_desc))
-    {
-      GimpPaintOptions *paint_options = GIMP_PAINT_OPTIONS (stroke_desc);
-      GimpPaintCore    *core;
+      break;
 
-      core = g_object_new (paint_options->paint_info->paint_type, NULL);
+    case GIMP_STROKE_METHOD_PAINT_CORE:
+      {
+        GimpPaintCore *core;
 
-      retval = gimp_paint_core_stroke_boundary (core, drawable,
-                                                paint_options,
-                                                segs_in, n_segs_in,
-                                                offset_x, offset_y);
+        core = g_object_new (stroke_desc->paint_info->paint_type, NULL);
 
-      g_object_unref (core);
+        retval = gimp_paint_core_stroke_boundary (core, drawable,
+                                                  stroke_desc->paint_options,
+                                                  segs_in, n_segs_in,
+                                                  offset_x, offset_y);
+
+        g_object_unref (core);
+      }
+      break;
+
+    default:
+      g_return_val_if_reached (FALSE);
     }
 
   return retval;
@@ -1514,13 +1520,12 @@ gimp_channel_set_color (GimpChannel   *channel,
 
   if (gimp_rgba_distance (&channel->color, color) > 0.0001)
     {
-      if (push_undo)
+      if (push_undo && gimp_item_is_attached (GIMP_ITEM (channel)))
         {
           GimpImage *gimage = gimp_item_get_image (GIMP_ITEM (channel));
 
-          if (gimage)
-            gimp_image_undo_push_channel_color (gimage, _("Set Channel Color"),
-                                                channel);
+          gimp_image_undo_push_channel_color (gimage, _("Set Channel Color"),
+                                              channel);
         }
 
       channel->color = *color;
@@ -1563,13 +1568,12 @@ gimp_channel_set_opacity (GimpChannel *channel,
 
   if (channel->color.a != opacity)
     {
-      if (push_undo)
+      if (push_undo && gimp_item_is_attached (GIMP_ITEM (channel)))
         {
           GimpImage *gimage = gimp_item_get_image (GIMP_ITEM (channel));
 
-          if (gimage)
-            gimp_image_undo_push_channel_color (gimage, _("Set Channel Opacity"),
-                                                channel);
+          gimp_image_undo_push_channel_color (gimage, _("Set Channel Opacity"),
+                                              channel);
         }
 
       channel->color.a = opacity;
@@ -1612,15 +1616,11 @@ void
 gimp_channel_push_undo (GimpChannel *channel,
                         const gchar *undo_desc)
 {
-  GimpImage *gimage;
-
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
+  g_return_if_fail (gimp_item_is_attached (GIMP_ITEM (channel)));
 
-  gimage = gimp_item_get_image (GIMP_ITEM (channel));
-
-  g_return_if_fail (GIMP_IS_IMAGE (gimage));
-
-  gimp_image_undo_push_mask (gimage, undo_desc, channel);
+  gimp_image_undo_push_mask (gimp_item_get_image (GIMP_ITEM (channel)),
+                             undo_desc, channel);
 
   gimp_drawable_invalidate_boundary (GIMP_DRAWABLE (channel));
 }
@@ -1715,6 +1715,9 @@ gimp_channel_feather (GimpChannel *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->feather (channel, radius_x, radius_y,
                                              push_undo);
 }
@@ -1725,6 +1728,9 @@ gimp_channel_sharpen (GimpChannel *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->sharpen (channel, push_undo);
 }
 
@@ -1735,6 +1741,9 @@ gimp_channel_clear (GimpChannel *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->clear (channel, undo_desc, push_undo);
 }
 
@@ -1744,6 +1753,9 @@ gimp_channel_all (GimpChannel *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->all (channel, push_undo);
 }
 
@@ -1753,6 +1765,9 @@ gimp_channel_invert (GimpChannel *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->invert (channel, push_undo);
 }
 
@@ -1764,6 +1779,9 @@ gimp_channel_border (GimpChannel *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->border (channel, radius_x, radius_y,
                                             push_undo);
 }
@@ -1776,6 +1794,9 @@ gimp_channel_grow (GimpChannel *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->grow (channel, radius_x, radius_y,
                                           push_undo);
 }
@@ -1789,6 +1810,9 @@ gimp_channel_shrink (GimpChannel  *channel,
 {
   g_return_if_fail (GIMP_IS_CHANNEL (channel));
 
+  if (! gimp_item_is_attached (GIMP_ITEM (channel)))
+    push_undo = FALSE;
+
   GIMP_CHANNEL_GET_CLASS (channel)->shrink (channel, radius_x, radius_y,
                                             edge_lock, push_undo);
 }
