@@ -63,12 +63,11 @@ gimp_drawable_bucket_fill (GimpDrawable       *drawable,
   GimpPattern *pattern = NULL;
 
   g_return_if_fail (GIMP_IS_DRAWABLE (drawable));
+  g_return_if_fail (gimp_item_is_attached (GIMP_ITEM (drawable)));
   g_return_if_fail (GIMP_IS_CONTEXT (context));
 
   gimage = gimp_item_get_image (GIMP_ITEM (drawable));
 
-  g_return_if_fail (GIMP_IS_IMAGE (gimage));
-
   if (fill_mode == GIMP_FG_BUCKET_FILL)
     {
       gimp_context_get_foreground (context, &color);
@@ -129,6 +128,7 @@ gimp_drawable_bucket_fill_full (GimpDrawable       *drawable,
   gboolean     selection;
 
   g_return_if_fail (GIMP_IS_DRAWABLE (drawable));
+  g_return_if_fail (gimp_item_is_attached (GIMP_ITEM (drawable)));
   g_return_if_fail (fill_mode != GIMP_PATTERN_BUCKET_FILL ||
                     GIMP_IS_PATTERN (pattern));
   g_return_if_fail (fill_mode == GIMP_PATTERN_BUCKET_FILL ||
@@ -136,7 +136,11 @@ gimp_drawable_bucket_fill_full (GimpDrawable       *drawable,
 
   gimage = gimp_item_get_image (GIMP_ITEM (drawable));
 
-  g_return_if_fail (GIMP_IS_IMAGE (gimage));
+  bytes     = gimp_drawable_bytes (drawable);
+  selection = gimp_drawable_mask_bounds (drawable, &x1, &y1, &x2, &y2);
+
+  if ((x1 == x2) || (y1 == y2))
+    return;
 
   if (fill_mode == GIMP_FG_BUCKET_FILL ||
       fill_mode == GIMP_BG_BUCKET_FILL)
@@ -164,9 +168,6 @@ gimp_drawable_bucket_fill_full (GimpDrawable       *drawable,
 
   gimp_set_busy (gimage->gimp);
 
-  bytes     = gimp_drawable_bytes (drawable);
-  selection = gimp_drawable_mask_bounds (drawable, &x1, &y1, &x2, &y2);
-
   /*  Do a seed bucket fill...To do this, calculate a new
    *  contiguous region. If there is a selection, calculate the
    *  intersection of this region with the existing selection.
