@@ -67,14 +67,21 @@ gboolean      gimp_drawable_transform_affine       (GimpDrawable           *draw
                                                     gint                    recursion_level,
                                                     gboolean                clip_result,
                                                     GimpProgress           *progress);
+
 gboolean      gimp_drawable_transform_flip         (GimpDrawable           *drawable,
                                                     GimpContext            *context,
-                                                    GimpOrientationType     flip_type);
-
+                                                    GimpOrientationType     flip_type,
+                                                    gboolean                auto_center,
+                                                    gdouble                 axis,
+                                                    gboolean                clip_result);
 
 gboolean      gimp_drawable_transform_rotate       (GimpDrawable           *drawable,
                                                     GimpContext            *context,
-                                                    GimpRotationType        rotate_type);
+                                                    GimpRotationType        rotate_type,
+                                                    gboolean                auto_center,
+                                                    gdouble                 center_x,
+                                                    gdouble                 center_y,
+                                                    gboolean                clip_result);
 
 TileManager * gimp_drawable_transform_cut          (GimpDrawable           *drawable,
                                                     GimpContext            *context,
