@@ -449,6 +449,13 @@ gimp_drawable_resize (GimpItem    *item,
   gint          copy_x, copy_y;
   gint          copy_width, copy_height;
 
+  /*  if the size doesn't change, this is a nop  */
+  if (new_width  == item->width  &&
+      new_height == item->height &&
+      offset_x   == 0            &&
+      offset_y   == 0)
+    return;
+
   new_offset_x = item->offset_x - offset_x;
   new_offset_y = item->offset_y - offset_y;
 
@@ -608,15 +615,11 @@ gimp_drawable_get_color_at (GimpPickable *pickable,
                             gint          y)
 {
   GimpDrawable *drawable = GIMP_DRAWABLE (pickable);
-  GimpImage    *gimage;
+  GimpImage    *gimage   = gimp_item_get_image (GIMP_ITEM (drawable));
   Tile         *tile;
   guchar       *src;
   guchar       *dest;
 
-  gimage = gimp_item_get_image (GIMP_ITEM (drawable));
-
-  g_return_val_if_fail (GIMP_IS_IMAGE (gimage), NULL);
-
   /* do not make this a g_return_if_fail() */
   if (x < 0 || x >= GIMP_ITEM (drawable)->width ||
       y < 0 || y >= GIMP_ITEM (drawable)->height)
@@ -892,6 +895,7 @@ gimp_drawable_apply_region (GimpDrawable         *drawable,
                             gint                  y)
 {
   g_return_if_fail (GIMP_IS_DRAWABLE (drawable));
+  g_return_if_fail (gimp_item_is_attached (GIMP_ITEM (drawable)));
   g_return_if_fail (src2PR != NULL);
 
   GIMP_DRAWABLE_GET_CLASS (drawable)->apply_region (drawable, src2PR,
@@ -912,6 +916,7 @@ gimp_drawable_replace_region (GimpDrawable *drawable,
                               gint          y)
 {
   g_return_if_fail (GIMP_IS_DRAWABLE (drawable));
+  g_return_if_fail (gimp_item_is_attached (GIMP_ITEM (drawable)));
   g_return_if_fail (src2PR != NULL);
   g_return_if_fail (maskPR != NULL);
 
@@ -932,6 +937,9 @@ gimp_drawable_set_tiles (GimpDrawable *drawable,
   g_return_if_fail (GIMP_IS_DRAWABLE (drawable));
   g_return_if_fail (tiles != NULL);
 
+  if (! gimp_item_is_attached (GIMP_ITEM (drawable)))
+    push_undo = FALSE;
+
   gimp_item_offsets (GIMP_ITEM (drawable), &offset_x, &offset_y);
 
   gimp_drawable_set_tiles_full (drawable, push_undo, undo_desc, tiles,
@@ -955,10 +963,12 @@ gimp_drawable_set_tiles_full (GimpDrawable       *drawable,
   g_return_if_fail (tiles != NULL);
   g_return_if_fail (tile_manager_bpp (tiles) == GIMP_IMAGE_TYPE_BYTES (type));
 
-  item = GIMP_ITEM (drawable);
-
+  item   = GIMP_ITEM (drawable);
   gimage = gimp_item_get_image (item);
 
+  if (! gimp_item_is_attached (GIMP_ITEM (drawable)))
+    push_undo = FALSE;
+
   if (item->width    != tile_manager_width (tiles)  ||
       item->height   != tile_manager_height (tiles) ||
       item->offset_x != offset_x                    ||
@@ -1016,6 +1026,7 @@ gimp_drawable_push_undo (GimpDrawable *drawable,
 
   item = GIMP_ITEM (drawable);
 
+  g_return_if_fail (gimp_item_is_attached (item));
   g_return_if_fail (sparse == FALSE ||
                     tile_manager_width (tiles) == gimp_item_width (item));
   g_return_if_fail (sparse == FALSE ||
@@ -1045,17 +1056,16 @@ gimp_drawable_push_undo (GimpDrawable *drawable,
 TileManager *
 gimp_drawable_shadow (GimpDrawable *drawable)
 {
-  GimpItem  *item;
-  GimpImage *gimage;
+  GimpItem *item;
 
   g_return_val_if_fail (GIMP_IS_DRAWABLE (drawable), NULL);
 
-  item   = GIMP_ITEM (drawable);
-  gimage = gimp_item_get_image (item);
+  item = GIMP_ITEM (drawable);
 
-  g_return_val_if_fail (GIMP_IS_IMAGE (gimage), NULL);
+  g_return_val_if_fail (gimp_item_is_attached (item), NULL);
 
-  return gimp_image_shadow (gimage, item->width, item->height,
+  return gimp_image_shadow (gimp_item_get_image (item),
+                            item->width, item->height,
                             drawable->bytes);
 }
 
@@ -1064,28 +1074,31 @@ gimp_drawable_merge_shadow (GimpDrawable *drawable,
                             gboolean      push_undo,
                             const gchar  *undo_desc)
 {
-  GimpImage   *gimage;
-  PixelRegion  shadowPR;
-  gint         x1, y1, x2, y2;
+  GimpImage *gimage;
+  gint       x, y, width, height;
 
   g_return_if_fail (GIMP_IS_DRAWABLE (drawable));
+  g_return_if_fail (gimp_item_is_attached (GIMP_ITEM (drawable)));
 
   gimage = gimp_item_get_image (GIMP_ITEM (drawable));
 
-  g_return_if_fail (GIMP_IS_IMAGE (gimage));
   g_return_if_fail (gimage->shadow != NULL);
 
   /*  A useful optimization here is to limit the update to the
    *  extents of the selection mask, as it cannot extend beyond
    *  them.
    */
-  gimp_drawable_mask_bounds (drawable, &x1, &y1, &x2, &y2);
-  pixel_region_init (&shadowPR, gimage->shadow,
-                     x1, y1, (x2 - x1), (y2 - y1), FALSE);
-  gimp_drawable_apply_region (drawable, &shadowPR,
-                              push_undo, undo_desc,
-                              GIMP_OPACITY_OPAQUE, GIMP_REPLACE_MODE,
-                              NULL, x1, y1);
+  if (gimp_drawable_mask_intersect (drawable, &x, &y, &width, &height))
+    {
+      PixelRegion shadowPR;
+
+      pixel_region_init (&shadowPR, gimage->shadow,
+                         x, y, width, height, FALSE);
+      gimp_drawable_apply_region (drawable, &shadowPR,
+                                  push_undo, undo_desc,
+                                  GIMP_OPACITY_OPAQUE, GIMP_REPLACE_MODE,
+                                  NULL, x, y);
+    }
 }
 
 void
@@ -1105,8 +1118,6 @@ gimp_drawable_fill (GimpDrawable      *drawable,
   item   = GIMP_ITEM (drawable);
   gimage = gimp_item_get_image (item);
 
-  g_return_if_fail (gimage != NULL);
-
   drawable_type = gimp_drawable_type (drawable);
 
   pixel_region_init (&destPR, gimp_drawable_data (drawable),
@@ -1213,11 +1224,16 @@ gimp_drawable_mask_bounds (GimpDrawable *drawable,
   g_return_val_if_fail (x2 != NULL, FALSE);
   g_return_val_if_fail (y2 != NULL, FALSE);
 
-  item   = GIMP_ITEM (drawable);
-  gimage = gimp_item_get_image (item);
+  item = GIMP_ITEM (drawable);
 
-  g_return_val_if_fail (gimage != NULL, FALSE);
+  *x1 = 0;
+  *y1 = 0;
+  *x2 = gimp_item_width  (item);
+  *y2 = gimp_item_height (item);
 
+  g_return_val_if_fail (gimp_item_is_attached (item), FALSE);
+
+  gimage    = gimp_item_get_image (item);
   selection = gimp_image_get_mask (gimage);
 
   if (GIMP_DRAWABLE (selection) != drawable &&
@@ -1243,6 +1259,59 @@ gimp_drawable_mask_bounds (GimpDrawable *drawable,
   return FALSE;
 }
 
+gboolean
+gimp_drawable_mask_intersect (GimpDrawable *drawable,
+                              gint         *x,
+                              gint         *y,
+                              gint         *width,
+                              gint         *height)
+{
+  GimpItem    *item;
+  GimpImage   *gimage;
+  GimpChannel *selection;
+
+  g_return_val_if_fail (GIMP_IS_DRAWABLE (drawable), FALSE);
+  g_return_val_if_fail (x != NULL, FALSE);
+  g_return_val_if_fail (y != NULL, FALSE);
+  g_return_val_if_fail (width  != NULL, FALSE);
+  g_return_val_if_fail (height != NULL, FALSE);
+
+  item = GIMP_ITEM (drawable);
+
+  *x      = 0;
+  *y      = 0;
+  *width  = gimp_item_width  (item);
+  *height = gimp_item_height (item);
+
+  g_return_val_if_fail (gimp_item_is_attached (item), FALSE);
+
+  gimage    = gimp_item_get_image (item);
+  selection = gimp_image_get_mask (gimage);
+
+  if (GIMP_DRAWABLE (selection) != drawable &&
+      gimp_channel_bounds (selection, x, y, width, height))
+    {
+      gint off_x, off_y;
+
+      gimp_item_offsets (item, &off_x, &off_y);
+
+      return gimp_rectangle_intersect (*x - off_x, *y - off_y,
+                                       *width - *x, *height - *y,
+                                       0, 0,
+                                       gimp_item_width (item),
+                                       gimp_item_height (item),
+                                       x, y,
+                                       width, height);
+    }
+
+  *x      = 0;
+  *y      = 0;
+  *width  = gimp_item_width  (item);
+  *height = gimp_item_height (item);
+
+  return TRUE;
+}
+
 gboolean
 gimp_drawable_has_alpha (const GimpDrawable *drawable)
 {
