@@ -54,10 +54,10 @@ GType      gimp_pattern_get_type     (void) G_GNUC_CONST;
 GimpData * gimp_pattern_new          (const gchar        *name,
                                       gboolean            stingy_memory_use);
 GimpData * gimp_pattern_get_standard (void);
-GimpData * gimp_pattern_load         (const gchar        *filename,
+GList    * gimp_pattern_load         (const gchar        *filename,
                                       gboolean            stingy_memory_use,
                                       GError            **error);
-GimpData * gimp_pattern_load_pixbuf  (const gchar        *filename,
+GList    * gimp_pattern_load_pixbuf  (const gchar        *filename,
                                       gboolean            stingy_memory_use,
                                       GError            **error);
 
