@@ -76,6 +76,9 @@ static const GimpDialogFactoryEntry toplevel_entries[] =
   FOREIGN ("gimp-palette-editor-color-dialog",     FALSE),
   FOREIGN ("gimp-colormap-editor-color-dialog",    FALSE),
 
+  FOREIGN ("gimp-keyboard-shortcuts-dialog",       TRUE),
+  FOREIGN ("gimp-controller-action-dialog",        TRUE),
+
   /*  ordinary toplevels  */
   TOPLEVEL ("gimp-image-new-dialog",
             dialogs_image_new_new,          FALSE, TRUE, FALSE),
@@ -165,7 +168,7 @@ static const GimpDialogFactoryEntry dock_entries[] =
             GIMP_HELP_PATH_DIALOG,
             dialogs_vectors_list_view_new, 0, FALSE),
   DOCKABLE ("gimp-indexed-palette",
-            N_("Colormap"), N_("Indexed Palette"), GIMP_STOCK_INDEXED_PALETTE,
+            N_("Colormap"), NULL, GIMP_STOCK_INDEXED_PALETTE,
             GIMP_HELP_INDEXED_PALETTE_DIALOG,
             dialogs_colormap_editor_new, 0, FALSE),
   DOCKABLE ("gimp-histogram-editor",
@@ -222,7 +225,7 @@ dialogs_init (Gimp            *gimp,
 
   global_dialog_factory = gimp_dialog_factory_new ("toplevel",
 						   gimp_get_user_context (gimp),
-						   NULL,
+						   menu_factory,
 						   NULL);
 
   global_toolbox_factory = gimp_dialog_factory_new ("toolbox",
