@@ -23,6 +23,7 @@
 #include "display-types.h"
 
 #include "core/gimp.h"
+#include "core/gimpcontext.h"
 #include "core/gimpimage.h"
 #include "core/gimplist.h"
 
@@ -52,19 +53,38 @@ gimp_displays_dirty (Gimp *gimp)
   return FALSE;
 }
 
+static void
+gimp_displays_image_dirty_callback (GimpImage     *image,
+                                    GimpDirtyMask  dirty_mask,
+                                    GimpContainer *container)
+{
+  if (image->dirty && image->disp_count > 0 &&
+      ! gimp_container_have (container, GIMP_OBJECT (image)))
+    gimp_container_add (container, GIMP_OBJECT (image));
+}
+
+static void
+gimp_displays_dirty_images_disconnect (GimpContainer *dirty_container,
+                                       GimpContainer *global_container)
+{
+  GQuark handler;
+
+  handler = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dirty_container),
+                                                "clean-handler"));
+  gimp_container_remove_handler (global_container, handler);
+
+  handler = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dirty_container),
+                                                "dirty-handler"));
+  gimp_container_remove_handler (global_container, handler);
+}
+
 static void
 gimp_displays_image_clean_callback (GimpImage     *image,
                                     GimpDirtyMask  dirty_mask,
                                     GimpContainer *container)
 {
   if (! image->dirty)
-    {
-      g_signal_handlers_disconnect_by_func (image,
-                                            gimp_displays_image_clean_callback,
-                                            container);
-
-      gimp_container_remove (container, GIMP_OBJECT (image));
-    }
+    gimp_container_remove (container, GIMP_OBJECT (image));
 }
 
 GimpContainer *
@@ -76,6 +96,25 @@ gimp_displays_get_dirty_images (Gimp *gimp)
     {
       GimpContainer *container = gimp_list_new_weak (GIMP_TYPE_IMAGE, FALSE);
       GList         *list;
+      GQuark         handler;
+
+      handler =
+        gimp_container_add_handler (gimp->images, "clean",
+                                    G_CALLBACK (gimp_displays_image_dirty_callback),
+                                    container);
+      g_object_set_data (G_OBJECT (container), "clean-handler",
+                         GINT_TO_POINTER (handler));
+
+      handler =
+        gimp_container_add_handler (gimp->images, "dirty",
+                                    G_CALLBACK (gimp_displays_image_dirty_callback),
+                                    container);
+      g_object_set_data (G_OBJECT (container), "dirty-handler",
+                         GINT_TO_POINTER (handler));
+
+      g_signal_connect_object (container, "disconnect",
+                               G_CALLBACK (gimp_displays_dirty_images_disconnect),
+                               G_OBJECT (gimp->images), 0);
 
       gimp_container_add_handler (container, "clean",
                                   G_CALLBACK (gimp_displays_image_clean_callback),
@@ -84,18 +123,14 @@ gimp_displays_get_dirty_images (Gimp *gimp)
                                   G_CALLBACK (gimp_displays_image_clean_callback),
                                   container);
 
-      for (list = GIMP_LIST (gimp->displays)->list;
+      for (list = GIMP_LIST (gimp->images)->list;
            list;
            list = g_list_next (list))
         {
-          GimpDisplay *display = list->data;
-          GimpImage   *image   = display->gimage;
+          GimpImage *image = list->data;
 
-          if (image->dirty &&
-              ! gimp_container_have (container, GIMP_OBJECT (image)))
-            {
-              gimp_container_add (container, GIMP_OBJECT (image));
-            }
+          if (image->dirty && image->disp_count > 0)
+            gimp_container_add (container, GIMP_OBJECT (image));
         }
 
       return container;
@@ -107,8 +142,6 @@ gimp_displays_get_dirty_images (Gimp *gimp)
 void
 gimp_displays_delete (Gimp *gimp)
 {
-  GimpDisplay *gdisp;
-
   g_return_if_fail (GIMP_IS_GIMP (gimp));
 
   /*  this removes the GimpDisplay from the list, so do a while loop
@@ -116,7 +149,7 @@ gimp_displays_delete (Gimp *gimp)
    */
   while (GIMP_LIST (gimp->displays)->list)
     {
-      gdisp = (GimpDisplay *) GIMP_LIST (gimp->displays)->list->data;
+      GimpDisplay *gdisp = GIMP_LIST (gimp->displays)->list->data;
 
       gimp_display_delete (gdisp);
     }
@@ -127,29 +160,44 @@ gimp_displays_reconnect (Gimp      *gimp,
                          GimpImage *old,
                          GimpImage *new)
 {
-  GList       *list;
-  GimpDisplay *gdisp;
+  GList *contexts = NULL;
+  GList *list;
 
   g_return_if_fail (GIMP_IS_GIMP (gimp));
   g_return_if_fail (GIMP_IS_IMAGE (old));
   g_return_if_fail (GIMP_IS_IMAGE (new));
 
+  /*  remember which contexts refer to old_gimage  */
+  for (list = gimp->context_list; list; list = g_list_next (list))
+    {
+      GimpContext *context = list->data;
+
+      if (gimp_context_get_image (context) == old)
+        contexts = g_list_prepend (contexts, list->data);
+    }
+
   for (list = GIMP_LIST (gimp->displays)->list;
        list;
        list = g_list_next (list))
     {
-      gdisp = list->data;
+      GimpDisplay *gdisp = list->data;
 
       if (gdisp->gimage == old)
 	gimp_display_reconnect (gdisp, new);
     }
+
+  /*  set the new_gimage on the remembered contexts (in reverse
+   *  order, since older contexts are usually the parents of
+   *  newer ones)
+   */
+  g_list_foreach (contexts, (GFunc) gimp_context_set_image, new);
+  g_list_free (contexts);
 }
 
 void
 gimp_displays_set_busy (Gimp *gimp)
 {
-  GList            *list;
-  GimpDisplayShell *shell;
+  GList *list;
 
   g_return_if_fail (GIMP_IS_GIMP (gimp));
 
@@ -157,7 +205,8 @@ gimp_displays_set_busy (Gimp *gimp)
        list;
        list = g_list_next (list))
     {
-      shell = GIMP_DISPLAY_SHELL (GIMP_DISPLAY (list->data)->shell);
+      GimpDisplayShell *shell =
+        GIMP_DISPLAY_SHELL (GIMP_DISPLAY (list->data)->shell);
 
       gimp_display_shell_set_override_cursor (shell, GDK_WATCH);
     }
@@ -166,8 +215,7 @@ gimp_displays_set_busy (Gimp *gimp)
 void
 gimp_displays_unset_busy (Gimp *gimp)
 {
-  GList            *list;
-  GimpDisplayShell *shell;
+  GList *list;
 
   g_return_if_fail (GIMP_IS_GIMP (gimp));
 
@@ -175,7 +223,8 @@ gimp_displays_unset_busy (Gimp *gimp)
        list;
        list = g_list_next (list))
     {
-      shell = GIMP_DISPLAY_SHELL (GIMP_DISPLAY (list->data)->shell);
+      GimpDisplayShell *shell =
+        GIMP_DISPLAY_SHELL (GIMP_DISPLAY (list->data)->shell);
 
       gimp_display_shell_unset_override_cursor (shell);
     }
