@@ -33,16 +33,15 @@
 
 /*  local function prototypes  */
 
-static void   gimp_display_update_handler           (GimpImage   *gimage,
-                                                     gint         x,
-                                                     gint         y,
-                                                     gint         w,
-                                                     gint         h,
-                                                     GimpDisplay *gdisp);
-static void   gimp_display_size_changed_handler     (GimpImage   *gimage,
-                                                     GimpDisplay *gdisp);
-static void   gimp_display_flush_handler            (GimpImage   *gimage,
-                                                     GimpDisplay *gdisp);
+static void   gimp_display_update_handler (GimpProjection *projection,
+                                           gboolean        now,
+                                           gint            x,
+                                           gint            y,
+                                           gint            w,
+                                           gint            h,
+                                           GimpDisplay    *gdisp);
+static void   gimp_display_flush_handler  (GimpImage      *gimage,
+                                           GimpDisplay    *gdisp);
 
 
 /*  public functions  */
@@ -68,12 +67,9 @@ gimp_display_connect (GimpDisplay *gdisp,
 
   g_object_ref (gimage);
 
-  g_signal_connect (gimage, "update",
+  g_signal_connect (gimage->projection, "update",
                     G_CALLBACK (gimp_display_update_handler),
                     gdisp);
-  g_signal_connect (gimage, "size_changed",
-                    G_CALLBACK (gimp_display_size_changed_handler),
-                    gdisp);
   g_signal_connect (gimage, "flush",
                     G_CALLBACK (gimp_display_flush_handler),
                     gdisp);
@@ -90,10 +86,7 @@ gimp_display_disconnect (GimpDisplay *gdisp)
   g_signal_handlers_disconnect_by_func (gdisp->gimage,
                                         gimp_display_flush_handler,
                                         gdisp);
-  g_signal_handlers_disconnect_by_func (gdisp->gimage,
-                                        gimp_display_size_changed_handler,
-                                        gdisp);
-  g_signal_handlers_disconnect_by_func (gdisp->gimage,
+  g_signal_handlers_disconnect_by_func (gdisp->gimage->projection,
                                         gimp_display_update_handler,
                                         gdisp);
 
@@ -118,40 +111,15 @@ gimp_display_disconnect (GimpDisplay *gdisp)
 /*  private functions  */
 
 static void
-gimp_display_update_handler (GimpImage   *gimage,
-                             gint         x,
-                             gint         y,
-                             gint         w,
-                             gint         h,
-                             GimpDisplay *gdisp)
+gimp_display_update_handler (GimpProjection *projection,
+                             gboolean        now,
+                             gint            x,
+                             gint            y,
+                             gint            w,
+                             gint            h,
+                             GimpDisplay    *gdisp)
 {
-  gimp_display_add_update_area (gdisp, x, y, w, h);
-}
-
-static void
-gimp_display_size_changed_handler (GimpImage   *gimage,
-                                   GimpDisplay *gdisp)
-{
-#if 0
-  /*  stop rendering and free all update area lists because
-   *  their coordinates have been invalidated by the resize
-   */
-  if (gdisp->idle_render.idle_id)
-    {
-      g_source_remove (gdisp->idle_render.idle_id);
-      gdisp->idle_render.idle_id = 0;
-    }
-
-  gimp_display_area_list_free (gdisp->update_areas);
-  gimp_display_area_list_free (gdisp->idle_render.update_areas);
-  gdisp->update_areas = NULL;
-  gdisp->idle_render.update_areas = NULL;
-#endif
-
-  gimp_display_add_update_area (gdisp,
-                                0, 0,
-                                gdisp->gimage->width,
-                                gdisp->gimage->height);
+  gimp_display_update_area (gdisp, now, x, y, w, h);
 }
 
 static void
