@@ -27,8 +27,8 @@ void   gimp_display_shell_drop_vectors  (GtkWidget     *widget,
                                          GimpViewable  *viewable,
                                          gpointer       data);
 void   gimp_display_shell_drop_svg      (GtkWidget     *widget,
-                                         const gchar   *svg_data,
-                                         gint           svg_data_length,
+                                         const guchar  *svg_data,
+                                         gsize          svg_data_length,
                                          gpointer       data);
 void   gimp_display_shell_drop_pattern  (GtkWidget     *widget,
                                          GimpViewable  *viewable,
@@ -39,8 +39,8 @@ void   gimp_display_shell_drop_color    (GtkWidget     *widget,
 void   gimp_display_shell_drop_buffer   (GtkWidget     *widget,
                                          GimpViewable  *viewable,
                                          gpointer       data);
-void   gimp_display_shell_drop_files    (GtkWidget     *widget,
-                                         GList         *files,
+void   gimp_display_shell_drop_uri_list (GtkWidget     *widget,
+                                         GList         *uri_list,
                                          gpointer       data);
 
 
