@@ -22,8 +22,11 @@
 #ifndef __COLOR_HISTORY_H__
 #define __COLOR_HISTORY_H__
 
-#define COLOR_HISTORY_SIZE 16
 
+#define COLOR_HISTORY_SIZE 12
+
+void   color_history_save        (void);
+void   color_history_restore     (void);
 
 gint   color_history_add         (const GimpRGB    *rgb);
 void   color_history_set         (gint              index,
@@ -31,8 +34,5 @@ void   color_history_set         (gint              index,
 void   color_history_get         (gint              index,
                                   GimpRGB          *rgb);
 
-void   color_history_add_from_rc (GimpRGB          *color);
-void   color_history_write       (GimpConfigWriter *writer);
-
 
 #endif /* __COLOR_HISTORY_H__ */
