@@ -60,7 +60,6 @@ static void   gimp_magnify_options_get_property (GObject         *object,
                                                  GParamSpec      *pspec);
 
 static void   gimp_magnify_options_reset        (GimpToolOptions *tool_options);
-static void   gimp_magnify_options_set_defaults (GimpToolOptions *tool_options);
 
 
 static GimpToolOptionsClass *parent_class = NULL;
@@ -174,14 +173,6 @@ gimp_magnify_options_get_property (GObject    *object,
 
 static void
 gimp_magnify_options_reset (GimpToolOptions *tool_options)
-{
-  gimp_magnify_options_set_defaults (tool_options);
-
-  GIMP_TOOL_OPTIONS_CLASS (parent_class)->reset (tool_options);
-}
-
-static void
-gimp_magnify_options_set_defaults (GimpToolOptions *tool_options)
 {
   GParamSpec *pspec;
 
@@ -191,6 +182,8 @@ gimp_magnify_options_set_defaults (GimpToolOptions *tool_options)
   if (pspec)
     G_PARAM_SPEC_BOOLEAN (pspec)->default_value =
       GIMP_DISPLAY_CONFIG (tool_options->tool_info->gimp->config)->resize_windows_on_zoom;
+
+  GIMP_TOOL_OPTIONS_CLASS (parent_class)->reset (tool_options);
 }
 
 GtkWidget *
@@ -234,7 +227,5 @@ gimp_magnify_options_gui (GimpToolOptions *tool_options)
                              1.0, 3.0, 1,
                              FALSE, 0.0, 0.0);
 
-  gimp_magnify_options_set_defaults (tool_options);
-
   return vbox;
 }
