@@ -239,8 +239,8 @@ gimp_perspective_tool_recalc (GimpTransformTool *tr_tool,
 {
   gimp_transform_matrix_perspective (tr_tool->x1,
                                      tr_tool->y1,
-                                     tr_tool->x2,
-                                     tr_tool->y2,
+                                     tr_tool->x2 - tr_tool->x1,
+                                     tr_tool->y2 - tr_tool->y1,
                                      tr_tool->trans_info[X0],
                                      tr_tool->trans_info[Y0],
                                      tr_tool->trans_info[X1],
