@@ -50,13 +50,10 @@
 
 #include "display/gimpdisplayshell-render.h"
 
-#include "gimpcolordialog.h"
 #include "gimpcolormapeditor.h"
 #include "gimpdnd.h"
-#include "gimpdialogfactory.h"
-#include "gimphelp-ids.h"
 #include "gimpmenufactory.h"
-#include "gimpwidgets-utils.h"
+#include "gimpuimanager.h"
 
 #include "gimp-intl.h"
 
@@ -127,9 +124,6 @@ static gboolean gimp_colormap_hex_entry_focus_out  (GtkEntry           *entry,
                                                     GdkEvent           *event,
                                                     GimpColormapEditor *editor);
 
-static void   gimp_colormap_edit_clicked           (GtkWidget          *widget,
-                                                    GimpColormapEditor *editor);
-
 static void   gimp_colormap_image_mode_changed     (GimpImage          *gimage,
                                                     GimpColormapEditor *editor);
 static void   gimp_colormap_image_colormap_changed (GimpImage          *gimage,
@@ -241,7 +235,6 @@ gimp_colormap_editor_init (GimpColormapEditor *editor)
 
   /*  Some helpful hints  */
   table = gtk_table_new (2, 2, FALSE);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 2);
   gtk_table_set_col_spacing (GTK_TABLE (table), 0, 4);
   gtk_table_set_row_spacing (GTK_TABLE (table), 0, 2);
   gtk_box_pack_end (GTK_BOX (editor), table, FALSE, FALSE, 0);
@@ -262,7 +255,7 @@ gimp_colormap_editor_init (GimpColormapEditor *editor)
   gtk_entry_set_width_chars (GTK_ENTRY (editor->color_entry), 8);
   gtk_entry_set_max_length (GTK_ENTRY (editor->color_entry), 6);
   gimp_table_attach_aligned (GTK_TABLE (table), 0, 1,
-                             _("He_x triplet:"), 0.0, 0.5,
+                             _("HTML notation:"), 0.0, 0.5,
                              editor->color_entry, 1, TRUE);
 
   g_signal_connect (editor->color_entry, "activate",
@@ -280,31 +273,22 @@ gimp_colormap_editor_constructor (GType                  type,
 {
   GObject            *object;
   GimpColormapEditor *editor;
-  gchar              *str;
 
   object = G_OBJECT_CLASS (parent_class)->constructor (type, n_params, params);
 
   editor = GIMP_COLORMAP_EDITOR (object);
 
   editor->edit_button =
-    gimp_editor_add_button (GIMP_EDITOR (editor),
-                            GIMP_STOCK_EDIT, _("Edit color"),
-                            GIMP_HELP_INDEXED_PALETTE_EDIT,
-                            G_CALLBACK (gimp_colormap_edit_clicked),
-                            NULL,
-                            editor);
+    gimp_editor_add_action_button (GIMP_EDITOR (editor), "colormap-editor",
+                                   "colormap-editor-edit-color",
+                                   NULL);
 
-  str = g_strdup_printf (_("Add color from FG\n%s  from BG"),
-                         gimp_get_mod_string (GDK_CONTROL_MASK));
   editor->add_button =
     gimp_editor_add_action_button (GIMP_EDITOR (editor), "colormap-editor",
                                    "colormap-editor-add-color-from-fg",
                                    "colormap-editor-add-color-from-bg",
                                    GDK_CONTROL_MASK,
                                    NULL);
-  gimp_help_set_help_data (editor->add_button, str,
-                           GIMP_HELP_INDEXED_PALETTE_ADD);
-  g_free (str);
 
   return object;
 }
@@ -653,8 +637,6 @@ gimp_colormap_editor_update_entries (GimpColormapEditor *editor)
 
       gtk_adjustment_set_value (editor->index_adjustment, 0);
       gtk_entry_set_text (GTK_ENTRY (editor->color_entry), "");
-
-      gtk_widget_set_sensitive (GIMP_EDITOR (editor)->button_box, FALSE);
     }
   else
     {
@@ -671,11 +653,6 @@ gimp_colormap_editor_update_entries (GimpColormapEditor *editor)
 
       gtk_widget_set_sensitive (editor->index_spinbutton, TRUE);
       gtk_widget_set_sensitive (editor->color_entry, TRUE);
-
-      gtk_widget_set_sensitive (GIMP_EDITOR (editor)->button_box, TRUE);
-
-      gtk_widget_set_sensitive (editor->add_button,
-                                gimp_image_get_colormap_size (gimage) < 256);
     }
 }
 
@@ -741,8 +718,16 @@ gimp_colormap_preview_button_press (GtkWidget          *widget,
       gimp_colormap_editor_selected (editor, bevent->state);
 
       if (bevent->type == GDK_2BUTTON_PRESS)
-        gimp_colormap_edit_clicked (editor->edit_button, editor);
+        {
+          GtkAction *action;
 
+          action = gimp_ui_manager_find_action (GIMP_EDITOR (editor)->ui_manager,
+                                                "colormap-editor",
+                                                "colormap-editor-edit-color");
+
+          if (action)
+            gtk_action_activate (action);
+        }
       return TRUE;
 
     case 2:
@@ -848,87 +833,13 @@ gimp_colormap_hex_entry_focus_out (GtkEntry           *entry,
   return FALSE;
 }
 
-static void
-gimp_colormap_color_dialog_update (GimpColorDialog      *color_dialog,
-                                   const GimpRGB        *color,
-                                   GimpColorDialogState  state,
-                                   GimpColormapEditor   *editor)
-{
-  GimpImage *gimage = GIMP_IMAGE_EDITOR (editor)->gimage;
-
-  switch (state)
-    {
-    case GIMP_COLOR_DIALOG_UPDATE:
-      break;
-
-    case GIMP_COLOR_DIALOG_OK:
-      gimp_image_set_colormap_entry (gimage, editor->col_index, color, TRUE);
-      gimp_image_flush (gimage);
-      /* Fall through */
-
-    case GIMP_COLOR_DIALOG_CANCEL:
-      gtk_widget_hide (editor->color_dialog);
-      break;
-    }
-}
-
-static void
-gimp_colormap_edit_clicked (GtkWidget          *widget,
-                            GimpColormapEditor *editor)
-{
-  GimpImage *gimage = GIMP_IMAGE_EDITOR (editor)->gimage;
-
-  if (gimage)
-    {
-      GimpRGB color;
-
-      gimp_rgba_set_uchar (&color,
-                           gimage->cmap[editor->col_index * 3],
-                           gimage->cmap[editor->col_index * 3 + 1],
-                           gimage->cmap[editor->col_index * 3 + 2],
-                           OPAQUE_OPACITY);
-
-      if (! editor->color_dialog)
-        {
-          GimpDialogFactory *toplevel_factory;
-
-          toplevel_factory = gimp_dialog_factory_from_name ("toplevel");
-
-          editor->color_dialog =
-            gimp_color_dialog_new (GIMP_VIEWABLE (gimage),
-                                   _("Edit Indexed Color"),
-                                   GIMP_STOCK_CONVERT_INDEXED,
-                                   _("Edit indexed image palette color"),
-                                   GTK_WIDGET (editor),
-                                   toplevel_factory,
-                                   "gimp-colormap-editor-color-dialog",
-                                   (const GimpRGB *) &color,
-                                   FALSE, FALSE);
-
-          g_signal_connect (editor->color_dialog, "destroy",
-                            G_CALLBACK (gtk_widget_destroyed),
-                            &editor->color_dialog);
-
-          g_signal_connect (editor->color_dialog, "update",
-                            G_CALLBACK (gimp_colormap_color_dialog_update),
-                            editor);
-        }
-      else
-        {
-          gimp_viewable_dialog_set_viewable (GIMP_VIEWABLE_DIALOG (editor->color_dialog),
-                                             GIMP_VIEWABLE (gimage));
-          gimp_color_dialog_set_color (GIMP_COLOR_DIALOG (editor->color_dialog),
-                                       &color);
-        }
-
-      gtk_window_present (GTK_WINDOW (editor->color_dialog));
-    }
-}
-
 static void
 gimp_colormap_image_mode_changed (GimpImage          *gimage,
                                   GimpColormapEditor *editor)
 {
+  if (editor->color_dialog)
+    gtk_widget_hide (editor->color_dialog);
+
   gimp_colormap_image_colormap_changed (gimage, -1, editor);
 }
 
