@@ -24,32 +24,8 @@
 
 #include "config.h"
 
-#include <glib.h>
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#include <errno.h>
-#include <fcntl.h>
-#include <sys/stat.h>
-
-#ifdef G_OS_WIN32
-#include <io.h>
-#ifndef S_IRUSR
-#define S_IRUSR _S_IREAD
-#endif
-#ifndef S_IWUSR
-#define S_IWUSR _S_IWRITE
-#endif
-#endif
-
 #include <gtk/gtk.h>
 
-#include "libgimpbase/gimpbase.h"
 #include "libgimpwidgets/gimpwidgets.h"
 
 #include "widgets-types.h"
@@ -57,36 +33,24 @@
 #include "core/gimp.h"
 
 #include "gimperrorconsole.h"
-#include "gimphelp-ids.h"
 #include "gimpmenufactory.h"
-#include "gimpwidgets-utils.h"
 
 #include "gimp-intl.h"
 
 
-static void gimp_error_console_class_init  (GimpErrorConsoleClass *klass);
-static void gimp_error_console_init        (GimpErrorConsole      *editor);
+static void  gimp_error_console_class_init  (GimpErrorConsoleClass *klass);
+static void  gimp_error_console_init        (GimpErrorConsole      *editor);
 
-static void gimp_error_console_destroy          (GtkObject        *object);
-static void gimp_error_console_unmap            (GtkWidget        *widget);
+static GObject * gimp_error_console_constructor  (GType             type,
+                                                  guint             n_params,
+                                                  GObjectConstructParam *params);
 
-static gboolean gimp_error_console_button_press (GtkWidget        *widget,
-                                                 GdkEventButton   *event,
-                                                 GimpErrorConsole *console);
-static void gimp_error_console_clear_clicked    (GtkWidget        *button,
-                                                 GimpErrorConsole *console);
-static void gimp_error_console_save_clicked     (GtkWidget        *button,
-                                                 GimpErrorConsole *console);
-static void gimp_error_console_save_ext_clicked (GtkWidget        *button,
-                                                 GdkModifierType   state,
-                                                 GimpErrorConsole *console);
-static void gimp_error_console_save_response    (GtkWidget        *dialog,
-                                                 gint              response_id,
-                                                 GimpErrorConsole *console);
+static void      gimp_error_console_destroy      (GtkObject        *object);
+static void      gimp_error_console_unmap        (GtkWidget        *widget);
 
-static gboolean gimp_error_console_write_file   (GtkTextBuffer    *text_buffer,
-                                                 const gchar      *path,
-                                                 gboolean          selection_only);
+static gboolean  gimp_error_console_button_press (GtkWidget        *widget,
+                                                  GdkEventButton   *event,
+                                                  GimpErrorConsole *console);
 
 
 static GimpEditorClass *parent_class = NULL;
@@ -123,23 +87,21 @@ gimp_error_console_get_type (void)
 static void
 gimp_error_console_class_init (GimpErrorConsoleClass *klass)
 {
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
-
-  object_class = GTK_OBJECT_CLASS (klass);
-  widget_class = GTK_WIDGET_CLASS (klass);
+  GObjectClass   *object_class     = G_OBJECT_CLASS (klass);
+  GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
+  GtkWidgetClass *widget_class     = GTK_WIDGET_CLASS (klass);
 
   parent_class = g_type_class_peek_parent (klass);
 
-  object_class->destroy = gimp_error_console_destroy;
-  widget_class->unmap   = gimp_error_console_unmap;
+  object_class->constructor = gimp_error_console_constructor;
+  gtk_object_class->destroy = gimp_error_console_destroy;
+  widget_class->unmap       = gimp_error_console_unmap;
 }
 
 static void
 gimp_error_console_init (GimpErrorConsole *console)
 {
   GtkWidget *scrolled_window;
-  gchar     *str;
 
   console->text_buffer = gtk_text_buffer_new (NULL);
 
@@ -170,29 +132,33 @@ gimp_error_console_init (GimpErrorConsole *console)
 		    G_CALLBACK (gimp_error_console_button_press),
 		    console);
 
-  console->clear_button =
-    gimp_editor_add_button (GIMP_EDITOR (console),
-                            GTK_STOCK_CLEAR, _("Clear errors"),
-                            GIMP_HELP_ERRORS_CLEAR,
-                            G_CALLBACK (gimp_error_console_clear_clicked),
-                            NULL,
-                            console);
+  console->file_dialog = NULL;
+}
 
-  str = g_strdup_printf (_("Save all errors\n"
-                           "%s  Save selection"),
-                         gimp_get_mod_string (GDK_SHIFT_MASK));
+static GObject *
+gimp_error_console_constructor (GType                  type,
+                                guint                  n_params,
+                                GObjectConstructParam *params)
+{
+  GObject          *object;
+  GimpErrorConsole *console;
+
+  object = G_OBJECT_CLASS (parent_class)->constructor (type, n_params, params);
+
+  console = GIMP_ERROR_CONSOLE (object);
+
+  console->clear_button =
+    gimp_editor_add_action_button (GIMP_EDITOR (console), "error-console",
+                                   "error-console-clear", NULL);
 
   console->save_button =
-    gimp_editor_add_button (GIMP_EDITOR (console),
-                            GTK_STOCK_SAVE_AS, str,
-                            GIMP_HELP_ERRORS_SAVE,
-                            G_CALLBACK (gimp_error_console_save_clicked),
-                            G_CALLBACK (gimp_error_console_save_ext_clicked),
-                            console);
+    gimp_editor_add_action_button (GIMP_EDITOR (console), "error-console",
+                                   "error-console-save-all",
+                                   "error-console-save-selection",
+                                   GDK_SHIFT_MASK,
+                                   NULL);
 
-  g_free (str);
-
-  console->file_dialog = NULL;
+  return object;
 }
 
 static void
@@ -304,149 +270,3 @@ gimp_error_console_button_press (GtkWidget        *widget,
 
   return FALSE;
 }
-
-static void
-gimp_error_console_clear_clicked (GtkWidget        *button,
-                                  GimpErrorConsole *console)
-{
-  GtkTextIter start_iter;
-  GtkTextIter end_iter;
-
-  gtk_text_buffer_get_start_iter (console->text_buffer, &start_iter);
-  gtk_text_buffer_get_end_iter (console->text_buffer, &end_iter);
-
-  gtk_text_buffer_delete (console->text_buffer, &start_iter, &end_iter);
-}
-
-static void
-gimp_error_console_save_clicked (GtkWidget        *button,
-                                 GimpErrorConsole *console)
-{
-  gimp_error_console_save_ext_clicked (button, 0, console);
-}
-
-static void
-gimp_error_console_save_ext_clicked (GtkWidget        *button,
-                                     GdkModifierType   state,
-                                     GimpErrorConsole *console)
-{
-  GtkFileChooser *chooser;
-
-  if (! gtk_text_buffer_get_selection_bounds (console->text_buffer,
-                                              NULL, NULL) &&
-      (state & GDK_SHIFT_MASK))
-    {
-      g_message (_("Cannot save. Nothing is selected."));
-      return;
-    }
-
-  if (console->file_dialog)
-    {
-      gtk_window_present (GTK_WINDOW (console->file_dialog));
-      return;
-    }
-
-  console->file_dialog =
-    gtk_file_chooser_dialog_new (_("Save Error Log to File"), NULL,
-                                 GTK_FILE_CHOOSER_ACTION_SAVE,
-
-                                 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                 GTK_STOCK_SAVE,   GTK_RESPONSE_OK,
-
-                                 NULL);
-
-  console->save_selection = (state & GDK_SHIFT_MASK) ? TRUE : FALSE;
-
-  g_object_add_weak_pointer (G_OBJECT (console->file_dialog),
-                             (gpointer *) &console->file_dialog);
-
-  chooser = GTK_FILE_CHOOSER (console->file_dialog);
-
-  gtk_window_set_screen (GTK_WINDOW (chooser), gtk_widget_get_screen (button));
-
-  gtk_window_set_position (GTK_WINDOW (chooser), GTK_WIN_POS_MOUSE);
-  gtk_window_set_role (GTK_WINDOW (chooser), "gimp-save-errors");
-
-  g_signal_connect (chooser, "response",
-		    G_CALLBACK (gimp_error_console_save_response),
-		    console);
-  g_signal_connect (chooser, "delete_event",
-		    G_CALLBACK (gtk_true),
-		    NULL);
-
-  gimp_help_connect (GTK_WIDGET (chooser), gimp_standard_help_func,
-		     GIMP_HELP_ERRORS_DIALOG, NULL);
-
-  gtk_widget_show (GTK_WIDGET (chooser));
-}
-
-static void
-gimp_error_console_save_response (GtkWidget        *dialog,
-                                  gint              response_id,
-                                  GimpErrorConsole *console)
-{
-  if (response_id == GTK_RESPONSE_OK)
-    {
-      gchar *filename;
-
-      filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-
-      if (! gimp_error_console_write_file (console->text_buffer, filename,
-                                           console->save_selection))
-        {
-          g_message (_("Error writing file '%s':\n%s"),
-                     gimp_filename_to_utf8 (filename), g_strerror (errno));
-          g_free (filename);
-          return;
-        }
-
-      g_free (filename);
-    }
-
-  gtk_widget_destroy (dialog);
-}
-
-static gboolean
-gimp_error_console_write_file (GtkTextBuffer *text_buffer,
-                               const gchar   *path,
-                               gboolean       selection_only)
-{
-  GtkTextIter  start_iter;
-  GtkTextIter  end_iter;
-  gint         fd;
-  gint         text_length;
-  gint         bytes_written;
-  gchar	      *text_contents;
-
-  fd = open (path, O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR);
-
-  if (fd == -1)
-    return FALSE;
-
-  if (selection_only)
-    gtk_text_buffer_get_selection_bounds (text_buffer, &start_iter, &end_iter);
-  else
-    gtk_text_buffer_get_bounds (text_buffer, &start_iter, &end_iter);
-
-  text_contents = gtk_text_buffer_get_text (text_buffer,
-					    &start_iter, &end_iter, TRUE);
-
-  text_length = strlen (text_contents);
-
-  if (text_contents && (text_length > 0))
-    {
-      bytes_written = write (fd, text_contents, text_length);
-
-      g_free (text_contents);
-      close (fd);
-
-      if (bytes_written != text_length)
-        return FALSE;
-      else
-	return TRUE;
-    }
-
-  close (fd);
-
-  return TRUE;
-}
