@@ -43,7 +43,11 @@ struct _GimpHistogramView
   gint                   start;
   gint                   end;
 
-  GdkGC                 *range_gc;
+  gint                   border_width;
+  gint                   subdivisions;
+
+  /* hack */
+  gboolean               light_histogram;
 };
 
 struct _GimpHistogramViewClass
@@ -59,17 +63,25 @@ struct _GimpHistogramViewClass
 GType           gimp_histogram_view_get_type      (void) G_GNUC_CONST;
 
 GtkWidget     * gimp_histogram_view_new           (gboolean              range);
+
 void            gimp_histogram_view_set_histogram (GimpHistogramView    *view,
                                                    GimpHistogram        *histogram);
 GimpHistogram * gimp_histogram_view_get_histogram (GimpHistogramView    *view);
+
 void            gimp_histogram_view_set_channel   (GimpHistogramView    *view,
                                                    GimpHistogramChannel  channel);
 GimpHistogramChannel gimp_histogram_view_get_channel (GimpHistogramView *view);
+
 void            gimp_histogram_view_set_scale     (GimpHistogramView    *view,
                                                    GimpHistogramScale    scale);
+GimpHistogramScale gimp_histogram_view_get_scale  (GimpHistogramView    *view);
+
 void            gimp_histogram_view_set_range     (GimpHistogramView    *view,
                                                    gint                  start,
                                                    gint                  end);
+void            gimp_histogram_view_get_range     (GimpHistogramView    *view,
+                                                   gint                 *start,
+                                                   gint                 *end);
 
 
 #endif /* __GIMP_HISTOGRAM_VIEW_H__ */
