@@ -36,9 +36,9 @@ struct _GimpTextEditor
 
   /*<  private  >*/
   GimpTextDirection  base_dir;
-  GtkWidget         *group;
   GtkWidget         *view;
   GtkWidget         *file_dialog;
+  GimpUIManager     *ui_manager;
 };
 
 struct _GimpTextEditorClass
@@ -51,7 +51,8 @@ struct _GimpTextEditorClass
 
 
 GType               gimp_text_editor_get_type      (void) G_GNUC_CONST;
-GtkWidget         * gimp_text_editor_new           (const gchar       *title);
+GtkWidget         * gimp_text_editor_new           (const gchar       *title,
+                                                    GimpMenuFactory   *menu_factory);
 
 void                gimp_text_editor_set_text      (GimpTextEditor    *editor,
                                                     const gchar       *text,
