@@ -22,17 +22,10 @@
 
 #include "config.h"
 
-#ifdef __GNUC__
-#warning GTK_DISABLE_DEPRECATED
-#endif
-#undef GTK_DISABLE_DEPRECATED
-
-#include <gtk/gtk.h>
+#include "gtkvwrapbox.h"
 
 #include "libgimpmath/gimpmath.h"
 
-#include "gtkvwrapbox.h"
-
 
 /* --- prototypes --- */
 static void    gtk_vwrap_box_class_init    (GtkVWrapBoxClass   *klass);
@@ -53,26 +46,28 @@ static gpointer parent_class = NULL;
 
 
 /* --- functions --- */
-GtkType
+GType
 gtk_vwrap_box_get_type (void)
 {
-  static GtkType vwrap_box_type = 0;
+  static GType vwrap_box_type = 0;
   
   if (!vwrap_box_type)
     {
-      static const GtkTypeInfo vwrap_box_info =
+      static const GTypeInfo vwrap_box_info =
       {
-	"GtkVWrapBox",
-	sizeof (GtkVWrapBox),
 	sizeof (GtkVWrapBoxClass),
-	(GtkClassInitFunc) gtk_vwrap_box_class_init,
-	(GtkObjectInitFunc) gtk_vwrap_box_init,
-        /* reserved_1 */ NULL,
-	/* reserved_2 */ NULL,
-	(GtkClassInitFunc) NULL,
+	NULL,		/* base_init */
+	NULL,		/* base_finalize */
+	(GClassInitFunc) gtk_vwrap_box_class_init,
+	NULL,		/* class_finalize */
+	NULL,		/* class_data */
+	sizeof (GtkVWrapBox),
+	0,		/* n_preallocs */
+	(GInstanceInitFunc) gtk_vwrap_box_init,
       };
       
-      vwrap_box_type = gtk_type_unique (GTK_TYPE_WRAP_BOX, &vwrap_box_info);
+      vwrap_box_type = g_type_register_static (GTK_TYPE_WRAP_BOX, "GtkVWrapBox",
+					       &vwrap_box_info, 0);
     }
   
   return vwrap_box_type;
@@ -81,17 +76,17 @@ gtk_vwrap_box_get_type (void)
 static void
 gtk_vwrap_box_class_init (GtkVWrapBoxClass *class)
 {
-  GtkObjectClass *object_class;
+  GObjectClass *object_class;
   GtkWidgetClass *widget_class;
   GtkContainerClass *container_class;
   GtkWrapBoxClass *wrap_box_class;
   
-  object_class = GTK_OBJECT_CLASS (class);
+  object_class = G_OBJECT_CLASS (class);
   widget_class = GTK_WIDGET_CLASS (class);
   container_class = GTK_CONTAINER_CLASS (class);
   wrap_box_class = GTK_WRAP_BOX_CLASS (class);
   
-  parent_class = gtk_type_class (GTK_TYPE_WRAP_BOX);
+  parent_class = g_type_class_peek_parent (class);
   
   widget_class->size_request = gtk_vwrap_box_size_request;
   widget_class->size_allocate = gtk_vwrap_box_size_allocate;
@@ -109,13 +104,7 @@ gtk_vwrap_box_init (GtkVWrapBox *vwbox)
 GtkWidget*
 gtk_vwrap_box_new (gboolean homogeneous)
 {
-  GtkVWrapBox *vwbox;
-
-  vwbox = GTK_VWRAP_BOX (gtk_widget_new (GTK_TYPE_VWRAP_BOX, NULL));
-
-  GTK_WRAP_BOX (vwbox)->homogeneous = homogeneous ? TRUE : FALSE;
-
-  return GTK_WIDGET (vwbox);
+  return g_object_new (GTK_TYPE_VWRAP_BOX, "homogeneous", homogeneous, NULL);
 }
 
 static inline void
