@@ -7,10 +7,10 @@
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
@@ -46,10 +46,16 @@ void    gimp_tile_ref_zero     (GimpTile  *tile);
 void    gimp_tile_unref        (GimpTile  *tile,
 				gboolean   dirty);
 void    gimp_tile_flush        (GimpTile  *tile);
+
 void    gimp_tile_cache_size   (gulong     kilobytes);
 void    gimp_tile_cache_ntiles (gulong     ntiles);
 
 
+/*  private function  */
+
+void    _gimp_tile_cache_flush_drawable (GimpDrawable *drawable);
+
+
 G_END_DECLS
 
 #endif /* __GIMP_TILE_H__ */
