@@ -472,7 +472,7 @@ _gp_config_read (GIOChannel  *channel,
                         (guint8 *) &config->check_type, 1, user_data))
     goto cleanup;
   if (! wire_read_int8 (channel,
-                        (guint8 *) &config->gimp_reserved_3, 1, user_data))
+                        (guint8 *) &config->show_help_button, 1, user_data))
     goto cleanup;
   if (! wire_read_int8 (channel,
                         (guint8 *) &config->gimp_reserved_4, 1, user_data))
@@ -545,7 +545,7 @@ _gp_config_write (GIOChannel  *channel,
     return;
   if (! wire_write_int8 (channel, (guint8*) &config->check_type, 1, user_data))
     return;
-  if (! wire_write_int8 (channel, (guint8*) &config->gimp_reserved_3, 1, user_data))
+  if (! wire_write_int8 (channel, (guint8*) &config->show_help_button, 1, user_data))
     return;
   if (! wire_write_int8 (channel, (guint8*) &config->gimp_reserved_4, 1, user_data))
     return;
