@@ -1,14 +1,14 @@
-/* LIBGIMP - The GIMP Library 
- * Copyright (C) 1995-1997 Peter Mattis and Spencer Kimball                
+/* LIBGIMP - The GIMP Library
+ * Copyright (C) 1995-1997 Peter Mattis and Spencer Kimball
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
@@ -26,16 +26,16 @@ G_BEGIN_DECLS
 
 
 void      gimp_hsv_set        (GimpHSV       *hsv,
-			       gdouble        h,
-			       gdouble        s,
-			       gdouble        v);
+			       gdouble        hue,
+			       gdouble        saturation,
+			       gdouble        value);
 void      gimp_hsv_clamp      (GimpHSV       *hsv);
 
 void      gimp_hsva_set       (GimpHSV       *hsva,
-			       gdouble        h,
-			       gdouble        s,
-			       gdouble        v,
-			       gdouble        a);
+			       gdouble        hue,
+			       gdouble        saturation,
+			       gdouble        value,
+			       gdouble        alpha);
 
 
 G_END_DECLS
