@@ -105,9 +105,31 @@ gimp_thumb_init (const gchar *creator,
   if (gimp_thumb_initialized)
     gimp_thumb_exit ();
 
-  thumb_dir = (thumb_basedir ?
-               g_strdup (thumb_basedir) :
-               g_build_filename (g_get_home_dir(), ".thumbnails", NULL));
+  if (thumb_basedir)
+    {
+      thumb_dir = g_strdup (thumb_basedir);
+    }
+  else
+    {
+      const gchar *home_dir = g_get_home_dir ();
+
+      if (home_dir && g_file_test (home_dir, G_FILE_TEST_IS_DIR))
+        {
+          thumb_dir = g_build_filename (home_dir, ".thumbnails", NULL);
+        }
+      else
+        {
+          gchar *name =
+            g_filename_to_utf8 (g_get_tmp_dir (), -1, NULL, NULL, NULL);
+
+          g_message (_("Cannot determine a valid home directory.\n"
+                       "Thumbnails will be stored in the folder for "
+                       "temporary files (%s) instead."), name);
+          g_free (name);
+
+          thumb_dir = g_build_filename (g_get_tmp_dir (), ".thumbnails", NULL);
+        }
+    }
 
   enum_class = g_type_class_ref (GIMP_TYPE_THUMB_SIZE);
 
@@ -357,7 +379,7 @@ gimp_thumb_name_from_uri_local (const gchar   *uri,
   if (strstr (uri, thumb_dir))
     return NULL;
 
-  filename = g_filename_from_uri (uri, NULL, NULL);
+  filename = _gimp_thumb_filename_from_uri (uri);
 
   if (filename)
     {
@@ -418,7 +440,7 @@ gimp_thumb_find_thumb (const gchar   *uri,
 
   if (! result)
     {
-      gchar *filename = g_filename_from_uri (uri, NULL, NULL);
+      gchar *filename = _gimp_thumb_filename_from_uri (uri);
 
       if (filename)
         {
@@ -575,6 +597,41 @@ _gimp_thumbs_delete_others (const gchar   *uri,
     }
 }
 
+gchar *
+_gimp_thumb_filename_from_uri (const gchar *uri)
+{
+  gchar *filename;
+  gchar *hostname;
+
+  g_return_val_if_fail (uri != NULL, NULL);
+
+  filename = g_filename_from_uri (uri, &hostname, NULL);
+
+  if (!filename)
+    return NULL;
+
+  if (hostname)
+    {
+      /*  we have a file: URI with a hostname                           */
+
+#ifdef G_OS_WIN32
+      /*  on Win32, create a valid UNC path and use it as the filename  */
+      gchar *tmp = g_build_filename ("//", hostname, filename, NULL);
+
+      g_free (filename);
+      filename = tmp;
+#else
+      /*  otherwise return NULL, caller should use URI then             */
+      g_free (filename);
+      filename = NULL;
+#endif
+
+      g_free (hostname);
+    }
+
+  return filename;
+}
+
 static void
 gimp_thumb_exit (void)
 {
