@@ -40,8 +40,6 @@ static void  gimp_int_store_finalize        (GObject           *object);
 static void  gimp_int_store_row_inserted    (GtkTreeModel      *model,
                                              GtkTreePath       *path,
                                              GtkTreeIter       *iter);
-static void  gimp_int_store_row_deleted     (GtkTreeModel      *model,
-                                             GtkTreePath       *path);
 static void  gimp_int_store_add_empty       (GimpIntStore      *store);
 
 
@@ -102,20 +100,18 @@ gimp_int_store_tree_model_init (GtkTreeModelIface *iface)
   parent_iface = g_type_interface_peek_parent (iface);
 
   iface->row_inserted = gimp_int_store_row_inserted;
-  iface->row_deleted  = gimp_int_store_row_deleted;
 }
 
 static void
 gimp_int_store_init (GimpIntStore *store)
 {
-  GType types[GIMP_INT_STORE_NUM_COLUMNS] =
-  {
-    G_TYPE_INT,       /*  GIMP_INT_STORE_VALUE      */
-    G_TYPE_STRING,    /*  GIMP_INT_STORE_LABEL      */
-    G_TYPE_STRING,    /*  GIMP_INT_STORE_STOCK_ID   */
-    GDK_TYPE_PIXBUF,  /*  GIMP_INT_STORE_PIXBUF     */
-    G_TYPE_POINTER    /*  GIMP_INT_STORE_USER_DATA  */
-  };
+  GType types[GIMP_INT_STORE_NUM_COLUMNS];
+
+  types[GIMP_INT_STORE_VALUE]     = G_TYPE_INT;
+  types[GIMP_INT_STORE_LABEL]     = G_TYPE_STRING;
+  types[GIMP_INT_STORE_STOCK_ID]  = G_TYPE_STRING;
+  types[GIMP_INT_STORE_PIXBUF]    = GDK_TYPE_PIXBUF;
+  types[GIMP_INT_STORE_USER_DATA] = G_TYPE_POINTER;
 
   store->empty_iter = NULL;
 
@@ -158,17 +154,6 @@ gimp_int_store_row_inserted (GtkTreeModel *model,
     }
 }
 
-static void
-gimp_int_store_row_deleted (GtkTreeModel *model,
-                            GtkTreePath  *path)
-{
-  if (parent_iface->row_deleted)
-    parent_iface->row_deleted (model, path);
-
-  if (gtk_tree_model_iter_n_children (model, NULL) == 0)
-    gimp_int_store_add_empty (GIMP_INT_STORE (model));
-}
-
 static void
 gimp_int_store_add_empty (GimpIntStore *store)
 {
