@@ -79,6 +79,12 @@ struct _GimpPreviewClass
 
   /* signal */
   void   (* invalidated) (GimpPreview   *preview);
+
+  /* Padding for future expansion */
+  void (* _gimp_reserved1) (void);
+  void (* _gimp_reserved2) (void);
+  void (* _gimp_reserved3) (void);
+  void (* _gimp_reserved4) (void);
 };
 
 
