@@ -193,7 +193,7 @@ compute_preview (gint x,
     }
   else
     {
-      gimp_palette_get_background (&background);
+      gimp_context_get_background (&background);
       gimp_rgb_set_alpha (&background, 1.0);
     }
 
