@@ -99,12 +99,14 @@
 #define HCANNONIZE(p, x)     (254*(((p).range_h - (p).range_l)*(x) + (p).range_l))
 #define POS_IN_TORUS(i,size) ((i < 0) ? size + i : ((size <= i) ? i - size : i))
 
-typedef struct
+typedef struct _WidgetEntry WidgetEntry;
+
+struct _WidgetEntry
 {
   GtkWidget  *widget;
   gpointer    value;
-  void      (*updater) ();
-} WidgetEntry;
+  void      (*updater) (WidgetEntry *);
+};
 
 enum
 {
@@ -1952,7 +1954,7 @@ CML_save_to_file_callback (GtkWidget *widget,
 
                                      NULL);
 
-      gimp_help_connect (dialog, gimp_standard_help_func, HELP_ID, NULL);
+      gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
       g_signal_connect (dialog, "response",
                         G_CALLBACK (CML_save_to_file_response),
@@ -2124,7 +2126,7 @@ CML_load_from_file_callback (GtkWidget *widget,
 
                                      NULL);
 
-      gimp_help_connect (dialog, gimp_standard_help_func, HELP_ID, NULL);
+      gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
       g_signal_connect (dialog, "response",
                         G_CALLBACK (CML_load_from_file_response),
