@@ -138,8 +138,7 @@ query (void)
                           G_N_ELEMENTS (args), 0,
                           args, NULL);
 
-  gimp_plugin_menu_register (PLUG_IN_NAME,
-                             N_("<Image>/Layer"));
+  gimp_plugin_menu_register (PLUG_IN_NAME, "<Image>/Layer");
 }
 
 static void
