@@ -1,7 +1,7 @@
 /* The GIMP -- an image manipulation program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
- * $Id: tga.c,v 1.48 2004/05/20 00:50:04 neo Exp $
+ * $Id: tga.c,v 1.50 2004/11/02 12:00:24 mitch Exp $
  * TrueVision Targa loading and saving file filter for the Gimp.
  * Targa code Copyright (C) 1997 Raphael FRANCOIS and Gordon Matzigkeit
  *
@@ -237,7 +237,6 @@ query (void)
                           G_N_ELEMENTS (load_return_vals),
                           load_args, load_return_vals);
 
-  gimp_plugin_menu_register ("file_tga_load", "<Load>");
   gimp_register_file_handler_mime ("file_tga_load", "image/x-tga");
   gimp_register_load_handler ("file_tga_load", "tga", "");
 
@@ -253,7 +252,6 @@ query (void)
                           G_N_ELEMENTS (save_args), 0,
                           save_args, NULL);
 
-  gimp_plugin_menu_register ("file_tga_save", "<Save>");
   gimp_register_file_handler_mime ("file_tga_save", "image/x-tga");
   gimp_register_save_handler ("file_tga_save", "tga", "");
 }
@@ -925,7 +923,7 @@ ReadImage (FILE        *fp,
   gimp_image_set_filename (image_ID, filename);
 
   if (info->colorMapType == 1)
-    gimp_image_set_cmap(image_ID, gimp_cmap, info->colorMapLength);
+    gimp_image_set_colormap(image_ID, gimp_cmap, info->colorMapLength);
 
   layer_ID = gimp_layer_new (image_ID,
 			     _("Background"),
@@ -1043,7 +1041,7 @@ save_image (const gchar *filename,
 
   if (dtype == GIMP_INDEXED_IMAGE || dtype == GIMP_INDEXEDA_IMAGE)
     {
-      gimp_cmap = gimp_image_get_cmap (image_ID, &num_colors);
+      gimp_cmap = gimp_image_get_colormap (image_ID, &num_colors);
 
       header[1] = 1; /* cmap type */
       header[2] = (tsvals.rle) ? 9 : 1;
