@@ -250,8 +250,7 @@ query (void)
 			  G_N_ELEMENTS (args), 0,
 			  args, NULL);
 
-  gimp_plugin_menu_register ("plug_in_warp",
-                             N_("<Image>/Filters/Map"));
+  gimp_plugin_menu_register ("plug_in_warp", "<Image>/Filters/Map");
 }
 
 static void
