@@ -20,7 +20,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * 
+ *
  */
 
 #ifndef __GFIG_PREVIEW_H__
@@ -28,10 +28,12 @@
 
 #define PREVIEW_SIZE     400
 
-GtkWidget      *make_preview            (void);
-void            gfig_update_stat_labels (void);
-void            gfig_pos_enable         (GtkWidget *widget,
-                                         gpointer   data);
-void            dialog_update_preview   (GimpDrawable *drawable);
+GtkWidget *make_preview            (void);
+
+gboolean   gfig_preview_expose     (GtkWidget    *widget,
+                                    GdkEvent     *event);
+
+void       gfig_pos_enable         (GtkWidget    *widget,
+                                    gpointer      data);
 
 #endif /* __GFIG_PREVIEW_H__ */
