@@ -20,20 +20,20 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * 
+ *
  */
 
 #ifndef __GFIG_STAR_H__
 #define __GFIG_STAR_H__
 
-gboolean   star_button_press       (GtkWidget      *widget,
-                                    GdkEventButton *event,
-                                    gpointer        data);
+void tool_options_star        (GtkWidget *notebook);
 
-void       d_update_star           (GdkPoint *pnt);
-void       d_star_start            (GdkPoint *pnt, gint shift_down);
-void       d_star_end              (GdkPoint *pnt, gint shift_down);
+void d_star_object_class_init (void);
+
+void d_star_start             (GdkPoint  *pnt,
+                               gboolean   shift_down);
+void d_star_end               (GdkPoint  *pnt,
+                               gboolean   shift_down);
 
-void       d_star_object_class_init (void);
 
 #endif /* __GFIG_STAR_H__ */
