@@ -62,7 +62,7 @@ settings_ok_cb(gpointer data)
       GTK_ENTRY(param->imagename->file)));
    g_strreplace(&info->title, gtk_entry_get_text(GTK_ENTRY(param->title)));
    g_strreplace(&info->author, gtk_entry_get_text(GTK_ENTRY(param->author)));
-   g_strreplace(&info->default_url, 
+   g_strreplace(&info->default_url,
 		gtk_entry_get_text(GTK_ENTRY(param->default_url)));
    gtk_text_buffer_get_bounds(param->description, &start, &end);
    description = gtk_text_buffer_get_text(param->description, &start, &end,
@@ -81,7 +81,7 @@ type_toggled_cb(GtkWidget *widget, gpointer data)
 }
 
 static SettingsDialog_t*
-create_settings_dialog()
+create_settings_dialog(void)
 {
    SettingsDialog_t *data = g_new(SettingsDialog_t, 1);
    GtkWidget *table, *view, *frame, *hbox, *label, *swin;
@@ -96,7 +96,7 @@ create_settings_dialog()
 
    create_label_in_table(table, 1, 0, _("Image name:"));
    data->imagename = browse_widget_new(_("Select Image File"));
-   gtk_table_attach_defaults(GTK_TABLE(table), data->imagename->hbox, 1, 2, 
+   gtk_table_attach_defaults(GTK_TABLE(table), data->imagename->hbox, 1, 2,
 			     1, 2);
 
    label = create_label_in_table(table, 2, 0, _("_Title:"));
@@ -113,43 +113,45 @@ create_settings_dialog()
    gtk_widget_set_size_request(view, -1, 128);
    gtk_widget_show(view);
 
+   gtk_label_set_mnemonic_widget (GTK_LABEL (label), view);
+
    swin = gtk_scrolled_window_new(NULL, NULL);
-   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(swin), 
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(swin),
 				       GTK_SHADOW_IN);
    gtk_table_attach(GTK_TABLE(table), swin, 1, 2, 5, 8,
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL,
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
-   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin), 
-				  GTK_POLICY_NEVER, 
+   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin),
+				  GTK_POLICY_NEVER,
 				  GTK_POLICY_AUTOMATIC);
    gtk_widget_show(swin);
    gtk_container_add(GTK_CONTAINER(swin), view);
 
    frame = gimp_frame_new(_("Map file format"));
    gtk_widget_show(frame);
-   gtk_table_attach_defaults(GTK_TABLE(table), frame, 1, 2, 9, 10);
-   hbox = gtk_hbox_new(FALSE, 1);
+   gtk_table_attach_defaults(GTK_TABLE(table), frame, 0, 2, 9, 10);
+   hbox = gtk_hbox_new(FALSE, 6);
    gtk_container_add(GTK_CONTAINER(frame), hbox);
    gtk_widget_show(hbox);
 
    data->ncsa = gtk_radio_button_new_with_mnemonic_from_widget(NULL, "_NCSA");
-   g_signal_connect(data->ncsa, "toggled", 
+   g_signal_connect(data->ncsa, "toggled",
 		    G_CALLBACK(type_toggled_cb), (gpointer) NCSA);
-   gtk_box_pack_start(GTK_BOX(hbox), data->ncsa, TRUE, TRUE, 0);
+   gtk_box_pack_start(GTK_BOX(hbox), data->ncsa, FALSE, FALSE, 0);
    gtk_widget_show(data->ncsa);
 
    data->cern = gtk_radio_button_new_with_mnemonic_from_widget(
       GTK_RADIO_BUTTON(data->ncsa), "C_ERN");
-   g_signal_connect(data->cern, "toggled", 
+   g_signal_connect(data->cern, "toggled",
 		    G_CALLBACK(type_toggled_cb), (gpointer) CERN);
-   gtk_box_pack_start(GTK_BOX(hbox), data->cern, TRUE, TRUE, 0);
+   gtk_box_pack_start(GTK_BOX(hbox), data->cern, FALSE, FALSE, 0);
    gtk_widget_show(data->cern);
-   
+
    data->csim = gtk_radio_button_new_with_mnemonic_from_widget(
       GTK_RADIO_BUTTON(data->cern), "C_SIM");
-   g_signal_connect(data->csim, "toggled", 
+   g_signal_connect(data->csim, "toggled",
 		    G_CALLBACK(type_toggled_cb), (gpointer) CSIM);
-   gtk_box_pack_start(GTK_BOX(hbox), data->csim, TRUE, TRUE, 0);
+   gtk_box_pack_start(GTK_BOX(hbox), data->csim, FALSE, FALSE, 0);
    gtk_widget_show(data->csim);
 
    return data;
