@@ -1,4 +1,4 @@
-/* $Id: maze.c,v 1.34 2004/10/12 21:48:36 mitch Exp $
+/* $Id: maze.c,v 1.37 2004/11/18 08:59:56 neo Exp $
  * This is a plug-in for the GIMP.
  * It draws mazes...
  *
@@ -37,32 +37,27 @@
  *
  */
 
-#ifndef SOLO_COMPILE
 #include "config.h"
-#endif
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef MAZE_DEBUG
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
 
-#include <gtk/gtk.h>
 #include "libgimp/gimp.h"
-#include "libgimp/stdplugins-intl.h"
+#include "libgimp/gimpui.h"
 
 #include "maze.h"
 
-extern gint      maze_dialog (void);
-static void      query  (void);
-static void      run    (const gchar      *name,
-			 gint              nparams,
-			 const GimpParam  *param,
-			 gint             *nreturn_vals,
-			 GimpParam       **return_vals);
-static void      maze   (GimpDrawable     *drawable);
+#include "libgimp/stdplugins-intl.h"
+
+
+static void      query     (void);
+static void      run       (const gchar      *name,
+                            gint              nparams,
+                            const GimpParam  *param,
+                            gint             *nreturn_vals,
+                            GimpParam       **return_vals);
+
+static void      maze      (GimpDrawable     *drawable);
 
 static void      mask_maze (gint32  selection_ID,
 			    guchar *maz,
@@ -75,6 +70,9 @@ static void      mask_maze (gint32  selection_ID,
 			    gint    deadx,
 			    gint    deady);
 
+/* In maze_face.c */
+extern gint      maze_dialog      (void);
+
 /* In algorithms.c */
 extern void      mazegen          (gint    pos,
 				   guchar *maz,
@@ -106,6 +104,7 @@ extern void      drawbox    (GimpPixelRgn *dest_rgn,
 			     guint         h,
 			     guint8        clr[4]);
 
+
 GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,    /* init_proc */
@@ -116,25 +115,26 @@ GimpPlugInInfo PLUG_IN_INFO =
 
 MazeValues mvals =
 {
-    /* Calling parameters */
-    5,      /* Passage width */
-    5,      /* Passage height */
-    0,     /* seed */
-    FALSE, /* Tileable? */
-    57,    /* multiple * These two had "Experiment with this?" comments */
-    1,     /* offset   * in the maz.c source, so, lets expiriment.  :) */
-    DEPTH_FIRST, /* Algorithm */
-    TRUE, /* random_seed */
+  5,           /* Passage width */
+  5,           /* Passage height */
+  0,           /* seed */
+  FALSE,       /* Tileable? */
+  57,          /* multiple * These two had "Experiment with this?" comments */
+  1,           /* offset   * in the maz.c source, so, lets expiriment.  :) */
+  DEPTH_FIRST, /* Algorithm */
+  TRUE,        /* random_seed */
 };
 
 GRand *gr;
 
 guint sel_w, sel_h;
 
-MAIN () /*;*/
+
+MAIN ()
+
 
 static void
-query ()
+query (void)
 {
   static GimpParamDef args[] =
   {
@@ -152,16 +152,11 @@ query ()
     { GIMP_PDB_INT16,    "offset",      "Offset (use 1)" }
   };
 
-  gchar *help;
-
-  help = g_strdup_printf ("Generates a maze using either the depth-first "
-                          "search method or Prim's algorithm.  Can make "
-                          "tileable mazes too.  See %s for more help.",
-                          MAZE_URL);
-
   gimp_install_procedure ("plug_in_maze",
 			  "Draws a maze.",
-			  help,
+			  "Generates a maze using either the depth-first "
+                          "search method or Prim's algorithm.  Can make "
+                          "tileable mazes too.",
 			  "Kevin Turner <kevint@poboxes.com>",
 			  "Kevin Turner",
 			  "1997, 1998",
@@ -173,8 +168,6 @@ query ()
 
   gimp_plugin_menu_register ("plug_in_maze",
                              "<Image>/Filters/Render/Pattern");
-
-  g_free (help);
 }
 
 static void
@@ -232,13 +225,13 @@ run (const gchar      *name,
 
       if (status == GIMP_PDB_SUCCESS)
 	{
-	  mvals.width = (gint16)    param[3].data.d_int16;
-	  mvals.height = (gint16)   param[4].data.d_int16;
-	  mvals.tile = (gint8)      param[5].data.d_int8;
-          mvals.algorithm = (gint8) param[6].data.d_int8;
-	  mvals.seed = (guint32)    param[7].data.d_int32;
-	  mvals.multiple = (gint16) param[8].data.d_int16;
-	  mvals.offset = (gint16)   param[9].data.d_int16;
+	  mvals.width     = (gint16)  param[3].data.d_int16;
+	  mvals.height    = (gint16)  param[4].data.d_int16;
+	  mvals.tile      = (gint8)   param[5].data.d_int8;
+          mvals.algorithm = (gint8)   param[6].data.d_int8;
+	  mvals.seed      = (guint32) param[7].data.d_int32;
+	  mvals.multiple  = (gint16)  param[8].data.d_int16;
+	  mvals.offset    = (gint16)  param[9].data.d_int16;
 
           if (mvals.random_seed)
             mvals.seed = g_random_int ();
