@@ -1,5 +1,5 @@
 /*
- * "$Id: gimp_color_window.c,v 1.15 2004/05/25 12:19:22 neo Exp $"
+ * "$Id: gimp_color_window.c,v 1.16 2004/11/04 10:06:22 mitch Exp $"
  *
  *   Main window code for Print plug-in for the GIMP.
  *
@@ -26,6 +26,11 @@
 
 #include <string.h>
 
+#ifdef __GNUC__
+#warning GTK_DISABLE_DEPRECATED
+#endif
+#undef GTK_DISABLE_DEPRECATED
+
 #include <gtk/gtk.h>
 
 #include <gimp-print/gimp-print.h>
