@@ -1,5 +1,5 @@
 /*
- * "$Id: print.c,v 1.66.2.1 2005/04/09 19:42:31 neo Exp $"
+ * "$Id: print.c,v 1.66.2.2 2005/04/09 23:55:13 neo Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -429,7 +429,7 @@ run (const gchar      *name,
 	      close (pipefd[0]);
 	      close (pipefd[1]);
 	      execl ("/bin/sh", "/bin/sh", "-c",
-                     g_shell_quote (stp_get_output_to (vars)), NULL);
+                     stp_get_output_to (vars), NULL);
 	      /* NOTREACHED */
 	      exit (1);
 	    } else {
@@ -1240,5 +1240,5 @@ get_system_printers (void)
 }
 
 /*
- * End of "$Id: print.c,v 1.66.2.1 2005/04/09 19:42:31 neo Exp $".
+ * End of "$Id: print.c,v 1.66.2.2 2005/04/09 23:55:13 neo Exp $".
  */
