@@ -56,6 +56,7 @@ typedef struct
 
   GtkWidget     *about_dialog;
 
+  gchar         *short_title;
   gchar         *title;
   gchar         *help_id;
   gchar         *last_command;
@@ -161,7 +162,6 @@ script_fu_interface (SFScript *script)
   GtkWidget    *vbox2;
   GtkSizeGroup *group;
   GSList       *list;
-  gchar        *title;
   gchar        *tmp;
   gint          i;
 
@@ -171,7 +171,18 @@ script_fu_interface (SFScript *script)
       ugly workaround for the fact that we can not process two
       scripts at a time.  */
   if (sf_interface != NULL)
-    return;
+    {
+      gchar *message =
+        g_strdup_printf ("%s\n\n%s",
+                         _("Script-Fu cannot process two scripts "
+                           "at the same time."),
+                         _("You are already running the \"%s\" script."));
+
+      g_message (message, sf_interface->short_title);
+      g_free (message);
+
+      return;
+    }
 
   g_return_if_fail (script != NULL);
 
@@ -190,22 +201,21 @@ script_fu_interface (SFScript *script)
   /* strip the first part of the menupath if it contains _("/Script-Fu/") */
   tmp = strstr (gettext (script->menu_path), _("/Script-Fu/"));
   if (tmp)
-    title = g_strdup (tmp + strlen (_("/Script-Fu/")));
+    sf_interface->short_title = g_strdup (tmp + strlen (_("/Script-Fu/")));
   else
-    title = g_strdup (gettext (script->menu_path));
+    sf_interface->short_title = g_strdup (gettext (script->menu_path));
 
   /* strip mnemonics from the menupath */
-  tmp = gimp_strip_uline (title);
+  tmp = gimp_strip_uline (sf_interface->short_title);
+  g_free (sf_interface->short_title);
+  sf_interface->short_title = tmp;
 
-  g_free (title);
-  title = tmp;
-
-  tmp = strstr (title, "...");
+  tmp = strstr (sf_interface->short_title, "...");
   if (tmp)
     *tmp = '\0';
 
-  sf_interface->title = g_strdup_printf (_("Script-Fu: %s"), title);
-  g_free (title);
+  sf_interface->title = g_strdup_printf (_("Script-Fu: %s"),
+                                         sf_interface->short_title);
 
   sf_interface->help_id = g_strdup (script->pdb_name);
 
@@ -308,11 +318,9 @@ script_fu_interface (SFScript *script)
 	      break;
 	    }
 
-          gimp_int_combo_box_set_active (GIMP_INT_COMBO_BOX (widget), *ID_ptr);
-
-          g_signal_connect (widget, "changed",
-                            G_CALLBACK (gimp_int_combo_box_get_active),
-                            ID_ptr);
+          gimp_int_combo_box_connect (GIMP_INT_COMBO_BOX (widget), *ID_ptr,
+                                      G_CALLBACK (gimp_int_combo_box_get_active),
+                                      ID_ptr);
 	  break;
 
 	case SF_COLOR:
@@ -409,9 +417,6 @@ script_fu_interface (SFScript *script)
                                             0,
                                             script->arg_defaults[i].sfa_adjustment.digits);
 	      break;
-
-	    default:
-	      break;
 	    }
 
           g_signal_connect (script->arg_values[i].sfa_adjustment.adj,
@@ -495,9 +500,6 @@ script_fu_interface (SFScript *script)
                             G_CALLBACK (script_fu_combo_callback),
                             &script->arg_values[i].sfa_option);
 	  break;
-
-	default:
-	  break;
 	}
 
       if (widget)
@@ -560,6 +562,7 @@ script_fu_interface_quit (SFScript *script)
   g_return_if_fail (script != NULL);
   g_return_if_fail (sf_interface != NULL);
 
+  g_free (sf_interface->short_title);
   g_free (sf_interface->title);
   g_free (sf_interface->help_id);
 
@@ -626,6 +629,16 @@ script_fu_combo_callback (GtkWidget *widget,
   option->history = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 }
 
+static void
+script_fu_string_update (gchar       **dest,
+                         const gchar  *src)
+{
+  if (*dest)
+    g_free (*dest);
+
+  *dest = g_strdup (src);
+}
+
 static void
 script_fu_pattern_callback (const gchar  *name,
                             gint          width,
@@ -635,10 +648,7 @@ script_fu_pattern_callback (const gchar  *name,
                             gboolean      closing,
                             gpointer      data)
 {
-  gchar **pname = data;
-
-  g_free (*pname);
-  *pname = g_strdup (name);
+  script_fu_string_update (data, name);
 }
 
 static void
@@ -648,10 +658,7 @@ script_fu_gradient_callback (const gchar   *name,
                              gboolean       closing,
                              gpointer       data)
 {
-  gchar **gname = data;
-
-  g_free (*gname);
-  *gname = g_strdup (name);
+  script_fu_string_update (data, name);
 }
 
 static void
@@ -659,10 +666,7 @@ script_fu_font_callback (const gchar *name,
                          gboolean     closing,
                          gpointer     data)
 {
-  gchar **fname = data;
-
-  g_free (*fname);
-  *fname = g_strdup (name);
+  script_fu_string_update (data, name);
 }
 
 static void
@@ -670,10 +674,7 @@ script_fu_palette_callback (const gchar *name,
                             gboolean     closing,
                             gpointer     data)
 {
-  gchar **fname = data;
-
-  g_free (*fname);
-  *fname = g_strdup (name);
+  script_fu_string_update (data, name);
 }
 
 static void
@@ -769,6 +770,10 @@ script_fu_ok (SFScript *script)
           break;
 
         case SF_VALUE:
+          g_free (arg_value->sfa_value);
+          arg_value->sfa_value =
+            g_strdup (gtk_entry_get_text (GTK_ENTRY (widget)));
+
           g_string_append (s, arg_value->sfa_value);
           break;
 
@@ -848,9 +853,6 @@ script_fu_ok (SFScript *script)
         case SF_OPTION:
           g_string_append_printf (s, "%d", arg_value->sfa_option.history);
           break;
-
-        default:
-          break;
         }
     }
 
@@ -959,9 +961,6 @@ script_fu_reset (SFScript *script)
           gtk_combo_box_set_active (GTK_COMBO_BOX (widget),
                                     script->arg_defaults[i].sfa_option.history);
           break;
-
-        default:
-          break;
         }
     }
 }
