@@ -26,17 +26,27 @@
 #error "config.h must be included prior to script-fu-intl.h"
 #endif
 
-#include "libgimp/gimpintl.h"
+#include <libintl.h>
+
+
+#define _(String) gettext (String)
+
+#ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#else
+#    define N_(String) (String)
+#endif
+
+#ifndef HAVE_BIND_TEXTDOMAIN_CODESET
+#    define bind_textdomain_codeset(Domain, Codeset) (Domain)
+#endif
 
 #define INIT_I18N()	G_STMT_START{			          \
-  setlocale (LC_ALL, ""); 				          \
-  bindtextdomain (GETTEXT_PACKAGE"-libgimp",                      \
-                  gimp_locale_directory ());                      \
-  bind_textdomain_codeset (GETTEXT_PACKAGE"-libgimp", "UTF-8");   \
   bindtextdomain (GETTEXT_PACKAGE"-script-fu",                    \
                   gimp_locale_directory ());                      \
   bind_textdomain_codeset (GETTEXT_PACKAGE"-script-fu", "UTF-8"); \
   textdomain (GETTEXT_PACKAGE"-script-fu");                       \
 }G_STMT_END
 
+
 #endif /* __SCRIPT_FU_INTL_H__ */
